@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2004.
+ * Copyright (c) Tony Bybell 1999-2008.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -11,10 +11,18 @@
 #include <gtk/gtk.h>
 #include "splay.h"
 
+#if WAVE_USE_GTK2
+#define set_winsize(w,x,y) gtk_window_set_default_size(GTK_WINDOW(w),(x),(y))
+void create_toolbar(GtkWidget *table);
+#else
+#define set_winsize(w,x,y) gtk_widget_set_usize(GTK_WIDGET(w),(x),(y))
+#endif
+
+GtkWidget *notebook = NULL;
+
 void bwmaketree(void);
 void bwlogbox(char *title, int width, ds_Tree *t, int display_mode);
 
-
 static ds_Tree *selectedtree=NULL;
 
 static int is_active=0;
@@ -51,9 +59,6 @@ static void unselect_row_callback(GtkWidget *widget, gint row, gint column,
 selectedtree=NULL;
 }
 
-
-
-
 int treebox_is_active(void)
 {
 return(is_active);
@@ -82,11 +87,14 @@ static void destroy_callback(GtkWidget *widget, GtkWidget *nothing)
 void treebox(char *title, GtkSignalFunc func, GtkWidget *old_window)
 {
     GtkWidget *scrolled_win;
-    GtkWidget *hbox;
-    GtkWidget *button5;
-    GtkWidget *frame2, *frameh;
+    GtkWidget *frame2;
     GtkWidget *table;
     GtkCList  *clist;
+#ifndef WAVE_USE_GTK2
+    GtkWidget *frameh;
+    GtkWidget *button5;
+    GtkWidget *hbox;
+#endif
 
     if(is_active) 
 	{
@@ -102,15 +110,29 @@ void treebox(char *title, GtkSignalFunc func, GtkWidget *old_window)
     gtk_window_set_title(GTK_WINDOW (window), title);
     gtk_signal_connect(GTK_OBJECT (window), "delete_event",
                        (GtkSignalFunc) destroy_callback, NULL);
-    gtk_widget_set_usize(GTK_WIDGET(window), 640, 600);
+    set_winsize(window, 640, 600);
 
 
     table = gtk_table_new (256, 1, FALSE);
     gtk_widget_show (table);
 
+#ifndef WAVE_USE_GTK2
     frame2 = gtk_frame_new (NULL);
-    gtk_container_border_width (GTK_CONTAINER (frame2), 3);
     gtk_widget_show(frame2);
+#else
+    frame2 = gtk_hpaned_new();
+    gtk_widget_show(frame2);
+
+    notebook = gtk_notebook_new();
+    gtk_notebook_set_tab_pos(GTK_NOTEBOOK(notebook), GTK_POS_TOP);
+    gtk_notebook_set_show_tabs(GTK_NOTEBOOK(notebook), ~0); 
+    gtk_notebook_set_show_border(GTK_NOTEBOOK(notebook), ~0);
+    gtk_notebook_set_scrollable(GTK_NOTEBOOK(notebook), ~0);
+    gtk_notebook_popup_enable(GTK_NOTEBOOK(notebook));
+  
+    gtk_widget_show(notebook);
+    gtk_paned_pack2(GTK_PANED(frame2), notebook, TRUE, TRUE);
+#endif
 
     gtk_table_attach (GTK_TABLE (table), frame2, 0, 1, 0, 255,
                         GTK_FILL | GTK_EXPAND,
@@ -137,15 +159,24 @@ void treebox(char *title, GtkSignalFunc func, GtkWidget *old_window)
     selectedtree=NULL;
 
     scrolled_win = gtk_scrolled_window_new (NULL, NULL);
+#ifndef WAVE_USE_GTK2
     gtk_widget_set_usize( GTK_WIDGET (scrolled_win), -1, 300);
+#else
+    gtk_widget_set_usize( GTK_WIDGET (scrolled_win), 150, 300);
+#endif
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_win),
                                       GTK_POLICY_AUTOMATIC,
                                       GTK_POLICY_AUTOMATIC);
     gtk_widget_show(scrolled_win);
     gtk_container_add (GTK_CONTAINER (scrolled_win), GTK_WIDGET (tree));
+
+#ifndef WAVE_USE_GTK2
     gtk_container_add (GTK_CONTAINER (frame2), scrolled_win);
+#else
+    gtk_paned_pack1(GTK_PANED(frame2), scrolled_win, TRUE, TRUE);
+#endif
 
-
+#ifndef WAVE_USE_GTK2
     frameh = gtk_frame_new (NULL);
     gtk_container_border_width (GTK_CONTAINER (frameh), 3);
     gtk_widget_show(frameh);
@@ -166,14 +197,39 @@ void treebox(char *title, GtkSignalFunc func, GtkWidget *old_window)
     gtk_box_pack_start (GTK_BOX (hbox), button5, TRUE, TRUE, 0);
 
     gtk_container_add (GTK_CONTAINER (frameh), hbox);
+#else
+    create_toolbar(table);
+#endif
+
     gtk_container_add (GTK_CONTAINER (window), table);
 
     gtk_widget_show(window);
 }
 
 /*
- * $Id: tree_widget.c,v 1.2 2007/08/26 21:35:39 gtkwave Exp $
+ * $Id: tree_widget.c,v 1.9 2008/12/20 05:45:03 gtkwave Exp $
  * $Log: tree_widget.c,v $
+ * Revision 1.9  2008/12/20 05:45:03  gtkwave
+ * gtk1 compatibility and -Wshadow warning fixes
+ *
+ * Revision 1.8  2008/11/24 03:26:52  gtkwave
+ * warnings cleanups
+ *
+ * Revision 1.7  2008/11/18 05:37:34  gtkwave
+ * code cleanups
+ *
+ * Revision 1.6  2008/11/18 04:15:26  gtkwave
+ * prelim support for text searching in rtlbrowse
+ *
+ * Revision 1.5  2008/11/17 22:36:14  gtkwave
+ * adding find widgets
+ *
+ * Revision 1.4  2008/11/16 02:17:47  gtkwave
+ * rtlbrowse updates for single integrated window
+ *
+ * Revision 1.3  2008/11/12 19:49:42  gtkwave
+ * changed usage of usize
+ *
  * Revision 1.2  2007/08/26 21:35:39  gtkwave
  * integrated global context management from SystemOfCode2007 branch
  *
