@@ -238,7 +238,7 @@ if ( (!(GLOBALS->ae2_info_f=fopen(info_fname, "rb"))) || (!(GLOBALS->ae2_info =
                 for(timestep = st_2; timestep <= en_2; timestep++)
                         {
 			char valstr[65];
-			uint64_t val;
+			uint64_t val = 0;
 			ae2_read_value(GLOBALS->ae2_info, &time_fr, timestep, valstr);
 
 			for(bit=0;bit<64;bit++)
@@ -280,12 +280,12 @@ if(indirect_fname)
 		fprintf(stderr, AET2_RDLOAD"Using indirect file '%s' for facility selection...\n", indirect_fname);
 		while(!feof(ind_h))
 			{
-			char *exp, *exp2, *exp3;
+			char *exp1, *exp2, *exp3;
 			void *regex;
 		
-			exp = fgetmalloc(ind_h);
-			if(!exp) continue;
-			exp2 = exp;
+			exp1 = fgetmalloc(ind_h);
+			if(!exp1) continue;
+			exp2 = exp1;
 			while(isspace(*exp2)) exp2++;
 
 			exp3 = exp2 + strlen(exp2) - 1;
@@ -323,7 +323,7 @@ if(indirect_fname)
 					}
 				}
 
-			free_2(exp);
+			free_2(exp1);
 			}
 	
 		fclose(ind_h); ind_h = NULL;
@@ -448,7 +448,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
 			{
 			int bit;
 			char valstr[33];
-			unsigned int val;
+			unsigned int val = 0;
 			ae2_read_value(GLOBALS->ae2_info, &info_fr, 0, valstr);
 
 			for(bit=0;bit<32;bit++)
@@ -694,7 +694,7 @@ return(GLOBALS->max_time);
 /*
  * ae2 callback
  */
-static void ae2_callback(uint64_t *time, unsigned int *facidx, char **value, unsigned int row)
+static void ae2_callback(uint64_t *tim, unsigned int *facidx, char **value, unsigned int row)
 {
 struct HistEnt *htemp = histent_calloc();
 struct lx2_entry *l2e = &GLOBALS->ae2_lx2_table[*facidx][row];
@@ -709,7 +709,7 @@ if(busycnt==WAVE_BUSY_ITER)
         busycnt = 0;
         }
 
-/* fprintf(stderr, "%lld %d %d %s\n", *time, *facidx, row, *value); */
+/* fprintf(stderr, "%lld %d %d %s\n", *tim, *facidx, row, *value); */
 
 if(f->length>1)        
         {
@@ -731,11 +731,11 @@ if(f->length>1)
 
 if(!GLOBALS->ae2_time_xlate)
 	{
-	htemp->time = (*time);
+	htemp->time = (*tim);
 	}
 	else
 	{
-	htemp->time = GLOBALS->ae2_time_xlate[(*time) - GLOBALS->ae2_start_cyc];
+	htemp->time = GLOBALS->ae2_time_xlate[(*tim) - GLOBALS->ae2_start_cyc];
 	}
 
 if(l2e->histent_head)
@@ -821,7 +821,6 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 		                        for(r=1;r<rows+1;r++)
 		                                {
 						nptr np; 
-						char *value;
 		                                uint64_t row = ae2_read_ith_sparse_row(GLOBALS->ae2, GLOBALS->ae2_fr[i].s, cyc, r);
 
 		                                GLOBALS->ae2_fr[i].row = row;
@@ -862,11 +861,11 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 
                         for(r=1;r<rows+1;r++)
                                 {
-				nptr np; 
+				/* nptr np; */
                                 uint64_t row = ae2_read_ith_sparse_row(GLOBALS->ae2, GLOBALS->ae2_fr[i].s, cyc, r);
 
                                 GLOBALS->ae2_fr[i].row = row;
-				np = GLOBALS->ae2_lx2_table[i][row].np;
+				/* np = GLOBALS->ae2_lx2_table[i][row].np; */
 				ncyc =	ae2_read_next_value(GLOBALS->ae2, GLOBALS->ae2_fr+i, cyc, buf);
 
 				if((ncyc > cyc) && (ncyc < mxcyc)) mxcyc = ncyc;
@@ -932,17 +931,17 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 
 		                        for(r=1;r<rows+1;r++)
 	        	                        {
-						nptr np; 
+						nptr npr; 
 		                                uint64_t row = ae2_read_ith_sparse_row(GLOBALS->ae2, GLOBALS->ae2_fr[i].s, step_cyc, r);
 
 		                                GLOBALS->ae2_fr[i].row = row;
-						np = GLOBALS->ae2_lx2_table[i][row].np;
+						npr = GLOBALS->ae2_lx2_table[i][row].np;
 
 						ae2_read_value(GLOBALS->ae2, GLOBALS->ae2_fr+i, step_cyc, buf);
-						if(strcmp(buf, np->mv.value))
+						if(strcmp(buf, npr->mv.value))
 							{
-							strcpy(np->mv.value, buf);
-							ae2_callback(&step_cyc, &i, &np->mv.value, row);
+							strcpy(npr->mv.value, buf);
+							ae2_callback(&step_cyc, &i, &npr->mv.value, row);
 							}
 
 						ncyc =	ae2_read_next_value(GLOBALS->ae2, GLOBALS->ae2_fr+i, step_cyc, buf);
@@ -962,15 +961,15 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 				if(ncyc!=step_cyc)
 					{
 					int offset2 = ncyc-cyc;
-					struct ae2_ncycle_autosort *t = autosort[offset2];
+					struct ae2_ncycle_autosort *ta = autosort[offset2];
 				
-					autofacs[i].next = t;
+					autofacs[i].next = ta;
 					autosort[offset2] = autofacs+i; 
 					}
 					else
 					{
-					struct ae2_ncycle_autosort *t = deadlist;
-					autofacs[i].next = t;
+					struct ae2_ncycle_autosort *ta = deadlist;
+					autofacs[i].next = ta;
 					deadlist = autofacs+i;
 					}
 				t = tn;
@@ -1265,8 +1264,14 @@ for(txidx=0;txidx<GLOBALS->numfacs;txidx++)
 /* ...of AET2_IS_PRESENT */
 
 /*
- * $Id: ae2.c,v 1.7 2008/06/17 18:03:45 gtkwave Exp $
+ * $Id: ae2.c,v 1.9 2008/12/25 03:21:57 gtkwave Exp $
  * $Log: ae2.c,v $
+ * Revision 1.9  2008/12/25 03:21:57  gtkwave
+ * -Wshadow warning fixes
+ *
+ * Revision 1.8  2008/09/27 19:08:39  gtkwave
+ * compiler warning fixes
+ *
  * Revision 1.7  2008/06/17 18:03:45  gtkwave
  * added time = -1 endcaps
  *
