@@ -690,6 +690,9 @@ if(!tinsertnext)
 	tinsertnext->t_prev=GLOBALS->traces.bufferlast;
 	}
 
+GLOBALS->traces.scroll_top = GLOBALS->traces.buffer;
+GLOBALS->traces.scroll_bottom = GLOBALS->traces.bufferlast;
+
 GLOBALS->traces.buffer=GLOBALS->traces.bufferlast=NULL;
 GLOBALS->traces.buffercount=0;
 
@@ -1103,8 +1106,11 @@ UpdateTracesVisible();
 }
 
 /*
- * $Id: analyzer.c,v 1.6 2008/08/05 17:49:39 gtkwave Exp $
+ * $Id: analyzer.c,v 1.7 2008/12/18 01:31:29 gtkwave Exp $
  * $Log: analyzer.c,v $
+ * Revision 1.7  2008/12/18 01:31:29  gtkwave
+ * integrated experimental autoscroll code on signal adds
+ *
  * Revision 1.6  2008/08/05 17:49:39  gtkwave
  * comment trace dnd fix
  *
