@@ -203,6 +203,9 @@ typedef struct
     Trptr    buffer;		/* cut/copy buffer of traces */
     Trptr    bufferlast;	/* last element of bufferchain */
     int      buffercount;	/* number of traces in buffer */
+
+    Trptr    scroll_top;	/* for autoscrolling */
+    Trptr    scroll_bottom;
   } Traces;
 
 
@@ -240,7 +243,7 @@ typedef struct TraceEnt
     unsigned minmax_valid : 1;	/* for d_minval, d_maxval */
 
     unsigned int flags;		/* see def below in TraceEntFlagBits */
-    unsigned int cached_flags;	/* used for analog to determine if need to recalculate */
+    unsigned int cached_flags;	/* used for tcl for saving flags during cut and paste */
 
     union
       {
@@ -329,8 +332,14 @@ char *attempt_vecmatch(char *s1, char *s2);
 #endif
 
 /*
- * $Id: analyzer.h,v 1.8 2008/07/18 17:27:00 gtkwave Exp $
+ * $Id: analyzer.h,v 1.10 2008/12/31 22:20:12 gtkwave Exp $
  * $Log: analyzer.h,v $
+ * Revision 1.10  2008/12/31 22:20:12  gtkwave
+ * adding more tcl commands
+ *
+ * Revision 1.9  2008/12/18 01:31:30  gtkwave
+ * integrated experimental autoscroll code on signal adds
+ *
  * Revision 1.8  2008/07/18 17:27:00  gtkwave
  * adding hierpack code
  *
