@@ -91,7 +91,7 @@ if(flags&(TR_ZEROFILL|TR_ONEFILL))
 	                		pnt[i]=whichfill;
 	                		}
 	
-				bits = pnt;
+				bits = (unsigned char *)pnt;
 				nbits = msi + 1;
 				}
 			}
@@ -108,7 +108,7 @@ if(flags&(TR_ZEROFILL|TR_ONEFILL))
 	
 				memcpy(pnt+i, bits, nbits);
 	
-				bits = pnt;
+				bits = (unsigned char *)pnt;
 				nbits = lsi + 1;
 				}
 			}
@@ -1526,8 +1526,11 @@ return(retval);
 }
 
 /*
- * $Id: baseconvert.c,v 1.7 2008/03/25 03:22:06 gtkwave Exp $
+ * $Id: baseconvert.c,v 1.8 2008/06/11 08:01:42 gtkwave Exp $
  * $Log: baseconvert.c,v $
+ * Revision 1.8  2008/06/11 08:01:42  gtkwave
+ * gcc 4.3.x compiler warning fixes
+ *
  * Revision 1.7  2008/03/25 03:22:06  gtkwave
  * expanded zero fill to include also a one fill (for pre-inverted nets)
  *
