@@ -20,6 +20,7 @@
 #include "lx2.h"
 #include "lxt2_read.h"
 #include "vcd.h"
+#include "extload.h"
 #include "debug.h"
 #include "bsearch.h"
 #include "strace.h"
@@ -210,6 +211,11 @@ if(GLOBALS->is_lx2)
 	{
 	import_lx2_trace(np);
 	}
+else
+if(GLOBALS->extload)
+	{
+	import_extload_trace(np);
+	}
 else
 	{
 	fprintf(stderr, "Internal error with mvlfac trace handling, exiting.\n");
@@ -874,7 +880,7 @@ if(nodepnt)
 		else
 		{
 		char *s1, *s2;
-		int i, root1len=0, root2len=0;
+		int root1len=0, root2len=0;
 		int l1, l2;
 
 		s1=symhi->n->nname;
@@ -1072,7 +1078,7 @@ if(nodepnt)
 		else
 		{
 		char *s1, *s2;
-		int i, root1len=0, root2len=0;
+		int root1len=0, root2len=0;
 		int l1, l2;
 
 		if(!direction)
@@ -1620,7 +1626,7 @@ nptr *narray;
 char *nam;
 int offset, len;
 eptr rc=NULL;
-exptr exp;
+exptr exp1;
 
 if(n->mv.mvlfac) import_trace(n);
 
@@ -1718,12 +1724,12 @@ if(!n->ext)
 		narray[i]->nname = (char *)malloc_2(len+1);
 		strcpy(narray[i]->nname, nam);
 
-		exp = (exptr) calloc_2(1, sizeof(struct ExpandReferences));
-		exp->parent=n;							/* point to parent */
-		exp->parentbit=i;
-		exp->actual = actual;
+		exp1 = (exptr) calloc_2(1, sizeof(struct ExpandReferences));
+		exp1->parent=n;							/* point to parent */
+		exp1->parentbit=i;
+		exp1->actual = actual;
 		actual += delta;
-		narray[i]->expansion = exp;					/* can be safely deleted if expansion set like here */
+		narray[i]->expansion = exp1;					/* can be safely deleted if expansion set like here */
 		}
 
 	for(i=0;i<n->numhist;i++)
@@ -1810,7 +1816,7 @@ int actual;
 nptr np;
 char *nam;
 int offset, len;
-exptr exp;
+exptr exp1;
 
 if(n->mv.mvlfac) import_trace(n);
 
@@ -1833,7 +1839,7 @@ if(!n->ext)
 		actual = n->ext->msi - bit;
 		}
 
-	if((bit>rgh)||(bit<lft))
+	if((actual>rgh)||(actual<lft))
 		{
 		DEBUG(fprintf(stderr, "Out of range\n"));
 		return(NULL);
@@ -1904,11 +1910,11 @@ if(!n->ext)
 	np->nname = (char *)malloc_2(len+1);
 	strcpy(np->nname, nam);
 
-	exp = (exptr) calloc_2(1, sizeof(struct ExpandReferences));
-	exp->parent=n;							/* point to parent */
-	exp->parentbit=bit;
-	exp->actual=actual;						/* actual bitnum in [] */
-	np->expansion = exp;						/* can be safely deleted if expansion set like here */
+	exp1 = (exptr) calloc_2(1, sizeof(struct ExpandReferences));
+	exp1->parent=n;							/* point to parent */
+	exp1->parentbit=bit;
+	exp1->actual=actual;						/* actual bitnum in [] */
+	np->expansion = exp1;						/* can be safely deleted if expansion set like here */
 
 	for(i=0;i<n->numhist;i++)
 		{
@@ -2165,8 +2171,8 @@ if(*w2=='-')
 else
 if(*w2=='>')
 	{
-	char *nptr=(*(w2+1)!=0)?(w2+1):NULL;
-	GLOBALS->shift_timebase_default_for_add=nptr?atoi_64(nptr):LLDescriptor(0);
+	char *wnptr=(*(w2+1)!=0)?(w2+1):NULL;
+	GLOBALS->shift_timebase_default_for_add=wnptr?atoi_64(wnptr):LLDescriptor(0);
 	}
 else
 if(*w2=='@')
@@ -2305,7 +2311,6 @@ else
 if(*w2=='!')
 	{
 	/* fill logical_mutex */
-	int i;
 	char ch;
 
 	for(i=0;i<6;i++)
@@ -2361,13 +2366,13 @@ if(*w2=='?')
 	/* fill st->type */
 	if(*(w2+1)=='\"')
 		{
-		int len = strlen(w2+2);
+		int lens = strlen(w2+2);
 		if(GLOBALS->shadow_string) free_2(GLOBALS->shadow_string);
 		GLOBALS->shadow_string=NULL;
 
-		if(len)
+		if(lens)
 			{
-			GLOBALS->shadow_string = malloc_2(len+1);		
+			GLOBALS->shadow_string = malloc_2(lens+1);		
 			strcpy(GLOBALS->shadow_string, w2+2);
 			}
 
@@ -2437,7 +2442,7 @@ else if (*w2 == '[')
 	/* Main window size.  */
 	int x, y;
 	sscanf (w, "%d %d", &x, &y);
-	set_window_size (x, y);
+	if(!GLOBALS->block_xy_update) set_window_size (x, y);
 	}
       }
     else if (strcmp (w2, "pos") == 0)
@@ -2447,9 +2452,14 @@ else if (*w2 == '[')
 	/* Main window position.  */
 	int x, y;
 	sscanf (w, "%d %d", &x, &y);
-	set_window_xypos (x, y);
+	if(!GLOBALS->block_xy_update) set_window_xypos (x, y);
 	}
       }
+    else if (strcmp (w2, "timestart") == 0)
+      {
+      sscanf(w, TTFormat, &GLOBALS->timestart_from_savefile);
+      GLOBALS->timestart_from_savefile_valid = 1;
+      }
 #if WAVE_USE_GTK2
     else if (strcmp (w2, "treeopen") == 0)
 	{
@@ -2462,9 +2472,50 @@ else if (*w2 == '[')
 		w++;
 		}
 
-	force_open_tree_node(w);
+	if(GLOBALS->ctree_main)
+		{
+		force_open_tree_node(w);
+		}
+		else
+		{
+		/* cache values until ctree_main is created */
+		struct string_chain_t *t = calloc_2(1, sizeof(struct string_chain_t));
+		t->str = strdup_2(w);
+
+		if(!GLOBALS->treeopen_chain_curr)
+			{
+			GLOBALS->treeopen_chain_head = GLOBALS->treeopen_chain_curr = t;
+			}
+			else
+			{
+			GLOBALS->treeopen_chain_curr->next = t;
+			GLOBALS->treeopen_chain_curr = t;
+			}
+		}
 	}
 #endif
+    else if (strcmp (w2, "markername") == 0)
+	{
+	char *pnt = w;
+	int which;
+
+	if((*pnt) && (isspace(*pnt))) pnt++;
+
+	if(*pnt)
+		{
+		which = (*pnt) - 'A';
+		if((which >=0) && (which <= 25))
+			{
+			pnt++;
+
+			if(*pnt)
+				{
+				if(GLOBALS->marker_names[which]) free_2(GLOBALS->marker_names[which]);
+				GLOBALS->marker_names[which] = strdup_2(pnt);
+				}
+			}
+		}
+	}
     else
       {
 	/* Unknown attribute.  Forget it.  */
@@ -2717,6 +2768,10 @@ break;			/* start grabbing chars from here */
 }
 
 sscanf(w2,"%s",prefix);
+if(*w2=='[')
+	{
+	}
+else
 if(*w2=='*')
 	{
 	}
@@ -2859,8 +2914,30 @@ return(made);
 /****************/
 
 /*
- * $Id: bitvec.c,v 1.6 2008/07/18 19:54:56 gtkwave Exp $
+ * $Id: bitvec.c,v 1.13 2009/01/27 07:04:28 gtkwave Exp $
  * $Log: bitvec.c,v $
+ * Revision 1.13  2009/01/27 07:04:28  gtkwave
+ * added extload external process loader capability
+ *
+ * Revision 1.12  2008/12/25 03:21:57  gtkwave
+ * -Wshadow warning fixes
+ *
+ * Revision 1.11  2008/12/11 21:08:15  gtkwave
+ * allow support for marker names which are strings
+ *
+ * Revision 1.10  2008/10/02 00:52:24  gtkwave
+ * added dnd of external filetypes into viewer
+ *
+ * Revision 1.9  2008/09/30 00:27:22  gtkwave
+ * fixed ExtractNodeSingleBit for vectors which do not have a zero for msb+lsb
+ *
+ * Revision 1.8  2008/09/26 17:05:09  gtkwave
+ * force open tree nodes in ctree on initial .sav file read (didn't happen
+ * before as ctree was not built yet)
+ *
+ * Revision 1.7  2008/08/24 21:55:27  gtkwave
+ * update for timestart line in savefiles
+ *
  * Revision 1.6  2008/07/18 19:54:56  gtkwave
  * hierpack and vecmatch fixes with removal of extra brackets
  *
