@@ -13,7 +13,7 @@
 #include "currenttime.h"
 #include "symbol.h"
 
-static char *time_prefix=" munpf";
+static char *time_prefix=WAVE_SI_UNITS;
 
 static char *maxtime_label_text="Maximum Time";
 static char *marker_label_text ="Marker Time";
@@ -21,6 +21,62 @@ static char *marker_label_text ="Marker Time";
 static char *maxtime_label_text_hpos="Max";
 static char *marker_label_text_hpos ="Marker";
 
+
+void fractional_timescale_fix(char *s)
+{
+char buf[32], sfx[2];
+int i, len;
+int prefix_idx = 0;
+
+if(*s != '0') return;
+
+len = strlen(s);
+for(i=0;i<len;i++)
+	{
+        if((s[i]!='0')&&(s[i]!='1')&&(s[i]!='.'))
+        	{
+		buf[i] = 0;
+                prefix_idx=i;
+                break;   
+                }
+		else
+		{
+		buf[i] = s[i];
+		}
+	}
+
+if(!strcmp(buf, "0.1"))
+	{
+	strcpy(buf, "100");
+	}
+else if(!strcmp(buf, "0.01"))
+	{
+	strcpy(buf, "10");
+	}
+else if(!strcmp(buf, "0.001"))
+	{
+	strcpy(buf, "1");
+	}
+else
+	{
+	return;
+	}
+
+len = strlen(WAVE_SI_UNITS);
+for(i=0;i<len-1;i++)
+	{
+	if(s[prefix_idx] == WAVE_SI_UNITS[i]) break;
+	}
+
+sfx[0] = WAVE_SI_UNITS[i+1];
+sfx[1] = 0;
+strcat(buf, sfx);
+strcat(buf, "s");
+/* printf("old time: '%s', new time: '%s'\n", s, buf); */
+strcpy(s, buf);
+}
+
+
 void update_maxmarker_labels(void)
 {
 if(GLOBALS->use_maxtime_display) 
@@ -61,10 +117,18 @@ if((pnt=GLOBALS->atoi_cont_ptr))
 	}
 
 if(!offs) return(rval);
-doffs=strchr(time_prefix, (int)dim);
-if(!doffs) return(rval); /* should *never* happen */
+if((dim=='S')||(dim=='s'))
+	{
+	doffs = time_prefix;
+	}
+	else
+	{
+	doffs=strchr(time_prefix, (int)dim);
+	if(!doffs) return(rval); /* should *never* happen */
+	}
 
 delta= (doffs-time_prefix) - (offs-time_prefix);
+
 if(delta<0)
 	{
 	for(i=delta;i<0;i++)
@@ -83,7 +147,7 @@ if(delta<0)
 return(rval);
 }
 
-void reformat_time(char *buf, TimeType val, char dim)
+void reformat_time_simple(char *buf, TimeType val, char dim)
 {
 char *pnt;
 int i, offset;
@@ -107,6 +171,81 @@ if(i)
 	}
 }
 
+void reformat_time(char *buf, TimeType val, char dim)
+{
+char *pnt;
+int i, offset, offsetfix;
+
+pnt=strchr(time_prefix, (int)dim);
+if(pnt) { offset=pnt-time_prefix; } else offset=0;
+
+for(i=offset; i>0; i--)
+	{
+	if(val%1000) break;
+	val=val/1000;
+	}
+
+if(GLOBALS->scale_to_time_dimension)
+	{
+	if(GLOBALS->scale_to_time_dimension == 's')
+		{
+		pnt = time_prefix;
+		}
+		else
+		{
+		pnt=strchr(time_prefix, (int)GLOBALS->scale_to_time_dimension);
+		}
+	if(pnt) 
+		{
+		offsetfix = pnt-time_prefix;
+		if(offsetfix != i)
+			{
+			int j;
+			int deltaexp = (offsetfix - i);
+			gdouble gval = (gdouble)val;
+			gdouble mypow = 1.0;
+
+			if(deltaexp > 0)
+				{
+				for(j=0;j<deltaexp;j++)
+					{
+					mypow *= 1000.0;
+					}
+				}
+			else
+				{
+				for(j=0;j>deltaexp;j--)
+					{
+					mypow /= 1000.0;
+					}
+				}
+
+			gval *= mypow;
+
+			if(GLOBALS->scale_to_time_dimension == 's')
+				{
+				sprintf(buf, "%.9g sec", gval);
+				}
+				else
+				{
+				sprintf(buf, "%.9g %cs", gval, GLOBALS->scale_to_time_dimension);
+				}
+
+			return; 
+			}
+		}
+	}
+
+if(i)
+	{
+	sprintf(buf, TTFormat" %cs", val, time_prefix[i]);
+	}
+	else
+	{
+	sprintf(buf, TTFormat" sec", val);
+	}
+}
+
 
 void reformat_time_as_frequency(char *buf, TimeType val, char dim)
 {
@@ -114,7 +253,7 @@ char *pnt;
 int offset;
 double k;
 
-static const double negpow[] = { 1.0, 1.0e-3, 1.0e-6, 1.0e-9, 1.0e-12, 1.0e-15 };
+static const double negpow[] = { 1.0, 1.0e-3, 1.0e-6, 1.0e-9, 1.0e-12, 1.0e-15, 1.0e-18, 1.0e-21 };
 
 pnt=strchr(time_prefix, (int)dim);
 if(pnt) { offset=pnt-time_prefix; } else offset=0;
@@ -136,7 +275,7 @@ if(val)
 void reformat_time_blackout(char *buf, TimeType val, char dim)
 {
 char *pnt;
-int i, offset;
+int i, offset, offsetfix;
 struct blackout_region_t *bt = GLOBALS->blackout_regions;
 char blackout = ' ';
 
@@ -160,6 +299,57 @@ for(i=offset; i>0; i--)
 	val=val/1000;
 	}
 
+if(GLOBALS->scale_to_time_dimension)
+	{
+	if(GLOBALS->scale_to_time_dimension == 's')
+		{
+		pnt = time_prefix;
+		}
+		else
+		{
+		pnt=strchr(time_prefix, (int)GLOBALS->scale_to_time_dimension);
+		}
+	if(pnt) 
+		{
+		offsetfix = pnt-time_prefix;
+		if(offsetfix != i)
+			{
+			int j;
+			int deltaexp = (offsetfix - i);
+			gdouble gval = (gdouble)val;
+			gdouble mypow = 1.0;
+
+			if(deltaexp > 0)
+				{
+				for(j=0;j<deltaexp;j++)
+					{
+					mypow *= 1000.0;
+					}
+				}
+			else
+				{
+				for(j=0;j>deltaexp;j--)
+					{
+					mypow /= 1000.0;
+					}
+				}
+
+			gval *= mypow;
+
+			if(GLOBALS->scale_to_time_dimension == 's')
+				{
+				sprintf(buf, "%.9g%csec", gval, blackout);
+				}
+				else
+				{
+				sprintf(buf, "%.9g%c%cs", gval, blackout, GLOBALS->scale_to_time_dimension);
+				}
+
+			return; 
+			}
+		}
+	}
+
 if(i)
 	{
 	sprintf(buf, TTFormat"%c%cs", val, blackout, time_prefix[i]);
@@ -464,6 +654,14 @@ switch(scale)
         case -14:       GLOBALS->time_scale = LLDescriptor(10);
         case -15:                                       GLOBALS->time_dimension = 'f'; break;
 
+        case -16:       GLOBALS->time_scale = LLDescriptor(100); GLOBALS->time_dimension = 'a'; break;
+        case -17:       GLOBALS->time_scale = LLDescriptor(10);
+        case -18:                                       GLOBALS->time_dimension = 'a'; break;
+
+        case -19:       GLOBALS->time_scale = LLDescriptor(100); GLOBALS->time_dimension = 'z'; break;
+        case -20:       GLOBALS->time_scale = LLDescriptor(10);
+        case -21:                                       GLOBALS->time_dimension = 'z'; break;
+
         case -7:        GLOBALS->time_scale = LLDescriptor(100); GLOBALS->time_dimension = 'n'; break;
         case -8:        GLOBALS->time_scale = LLDescriptor(10);
         case -9:
@@ -472,8 +670,23 @@ switch(scale)
 }
 
 /*
- * $Id: currenttime.c,v 1.7 2008/02/19 22:56:11 gtkwave Exp $
+ * $Id: currenttime.c,v 1.12 2008/12/28 03:12:27 gtkwave Exp $
  * $Log: currenttime.c,v $
+ * Revision 1.12  2008/12/28 03:12:27  gtkwave
+ * adjusted fractional part of %g
+ *
+ * Revision 1.11  2008/12/28 03:03:33  gtkwave
+ * Added scale_to_time_dimension rc variable and menu options.
+ *
+ * Revision 1.10  2008/10/14 20:44:39  gtkwave
+ * fixed unformat time bug when base time is in seconds
+ *
+ * Revision 1.9  2008/09/27 19:08:39  gtkwave
+ * compiler warning fixes
+ *
+ * Revision 1.8  2008/09/17 04:33:38  gtkwave
+ * support for smaller timescales in VCD files
+ *
  * Revision 1.7  2008/02/19 22:56:11  gtkwave
  * rtlbrowse update to handle aet time substitutions
  *
