@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2008
+ * Copyright (c) Tony Bybell 1999-2009
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,9 +20,10 @@
 #include "regex_wave.h"
 #include "translate.h"
 
-#define WAVE_VERSION_INFO "GTKWave Analyzer v3.1.13 (w)1999-2008 BSI"
+#define WAVE_VERSION_INFO "GTKWave Analyzer v3.2.0 (w)1999-2009 BSI"
 
 #define WAVE_INF_SCALING (0.5)
+#define WAVE_SI_UNITS " munpfaz"
 
 /* for dnd */
 #define WAVE_DRAG_TAR_NAME_0         "text/plain"
@@ -41,7 +42,7 @@ struct blackout_region_t *next;
 TimeType bstart, bend;
 };
 
-
+void fractional_timescale_fix(char *);
 char *convert_ascii(Trptr t, vptr v);
 char *convert_ascii_vec(Trptr t, char *vec);
 char *convert_ascii_real(double *d);
@@ -109,7 +110,7 @@ void dump_open_tree_nodes(FILE *wave, xl_Tree *t);
 void force_open_tree_node(char *name);
 void select_tree_node(char *name);
 
-void dnd_setup(GtkWidget *src, GtkWidget *widget); /* dnd from gtk2 tree to signalwindow */
+void dnd_setup(GtkWidget *src, GtkWidget *widget, int enable_receive); /* dnd from gtk2 tree to signalwindow */
 void treeview_select_all_callback(void); /* gtk2 */
 void treeview_unselect_all_callback(void); /* gtk2 */
 
@@ -139,11 +140,15 @@ void help_text_bold(char *str);
 void dnd_error(void);
 
 void reformat_time(char *buf, TimeType val, char dim);
+void reformat_time_simple(char *buf, TimeType val, char dim);
 TimeType unformat_time(const char *buf, char dim);
 void time_trunc_set(void);
 TimeType time_trunc(TimeType t);
 void exponent_to_time_scale(signed char scale);
 
+void from_entry_callback(GtkWidget *widget, GtkWidget *entry);
+void to_entry_callback(GtkWidget *widget, GtkWidget *entry);
+
 void load_all_fonts(void);
 
 /* logfile adds */
@@ -154,6 +159,7 @@ void update_endcap_times_for_partial_vcd(void);
 
 /* mouseover support */
 void move_mouseover(Trptr t, gint xin, gint yin, TimeType tim);
+void move_mouseover_sigs(Trptr t, gint xin, gint yin, TimeType tim);
 
 /* session swapping */
 gint install_keypress_handler(void);
@@ -168,8 +174,35 @@ void do_popup_menu (GtkWidget *my_widget, GdkEventButton *event);
 #endif
 
 /*
- * $Id: currenttime.h,v 1.45 2008/08/21 03:48:45 gtkwave Exp $
+ * $Id: currenttime.h,v 1.54 2009/02/17 03:20:35 gtkwave Exp $
  * $Log: currenttime.h,v $
+ * Revision 1.54  2009/02/17 03:20:35  gtkwave
+ * promote to 3.2.0
+ *
+ * Revision 1.53  2009/01/16 19:27:00  gtkwave
+ * added more tcl commands
+ *
+ * Revision 1.52  2009/01/10 19:53:52  gtkwave
+ * documentation updates
+ *
+ * Revision 1.51  2008/12/28 03:03:33  gtkwave
+ * Added scale_to_time_dimension rc variable and menu options.
+ *
+ * Revision 1.50  2008/12/09 00:36:42  gtkwave
+ * added mouseover support for signal window
+ *
+ * Revision 1.49  2008/10/21 04:04:28  gtkwave
+ * getting ready for version bump
+ *
+ * Revision 1.48  2008/09/17 04:33:38  gtkwave
+ * support for smaller timescales in VCD files
+ *
+ * Revision 1.47  2008/09/16 00:01:23  gtkwave
+ * prelim drag and drop from external apps (now disabled)
+ *
+ * Revision 1.46  2008/08/22 20:19:12  gtkwave
+ * fix for strings in vcd recoder
+ *
  * Revision 1.45  2008/08/21 03:48:45  gtkwave
  * promote to 3.1.13
  *
