@@ -113,6 +113,7 @@ void *malloc_2(size_t size);
 void *realloc_2(void *ptr, size_t size);
 void *calloc_2(size_t nmemb, size_t size);
 char *strdup_2(const char *s);
+char *strdup_2s(const char *s);
 
 char *tmpnam_2(char *s, int *fd);  /* mimic functionality of tmpnam() */
 
@@ -163,6 +164,9 @@ char stems_name[PATH_MAX+1];
 
 struct gtkwave_annotate_ipc_t
 {
+char matchword[4];			/* match against WAVE_MATCHWORD string */
+char time_string[40];			/* formatted marker time */
+
 TimeType marker;
 unsigned marker_set : 1;
 
@@ -191,8 +195,14 @@ unsigned viewer_is_initialized : 1;
 #endif
 
 /*
- * $Id: debug.h,v 1.4 2008/07/01 18:51:06 gtkwave Exp $
+ * $Id: debug.h,v 1.6 2009/01/20 06:11:48 gtkwave Exp $
  * $Log: debug.h,v $
+ * Revision 1.6  2009/01/20 06:11:48  gtkwave
+ * added gtkwave::getDisplayedSignals command
+ *
+ * Revision 1.5  2009/01/13 22:39:24  gtkwave
+ * compile fixes for mingw
+ *
  * Revision 1.4  2008/07/01 18:51:06  gtkwave
  * compiler warning fixes for amd64
  *
