@@ -114,7 +114,7 @@ if(GLOBALS->script_handle)
 	}
 
 
-#if !GTK_CHECK_VERSION(2,4,0)
+#if defined __MINGW32__ || !GTK_CHECK_VERSION(2,4,0)
 
 fileselbox_old(title, filesel_path, ok_func, notok_func, pattn);
 return;
@@ -159,6 +159,13 @@ if(*GLOBALS->fileselbox_text && (!g_path_is_absolute(*GLOBALS->fileselbox_text))
 #endif
 #endif
 	}
+	else
+	{
+	if(*GLOBALS->fileselbox_text)
+		{
+		can_set_filename = 1;
+		}
+	}
 
 if(is_writemode)
 	{
@@ -277,8 +284,14 @@ fix_suffix:                     s2 = malloc_2(strlen(s) + strlen(suffix) + 1);
 }
 
 /*
- * $Id: file.c,v 1.9 2008/02/27 16:23:00 gtkwave Exp $
+ * $Id: file.c,v 1.11 2009/01/13 22:56:47 gtkwave Exp $
  * $Log: file.c,v $
+ * Revision 1.11  2009/01/13 22:56:47  gtkwave
+ * revert to old file chooser in mingw as new one can't be resized
+ *
+ * Revision 1.10  2008/11/19 19:08:34  gtkwave
+ * add tcl menu option, update file requester name reentrancy code
+ *
  * Revision 1.9  2008/02/27 16:23:00  gtkwave
  * fixed potential file chooser crash
  *
