@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Kermin Elliott Fleming 2007-2008.
+ * Copyright (c) Kermin Elliott Fleming 2007-2009.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -90,8 +90,10 @@ NULL, /* ae2_regex_head */
  */
 TR_RJUSTIFY, /* default_flags 5 */
 {0, 0, 0, 0, 0, 0, 0}, /* tims 6 */
-{0, 0, NULL, NULL, NULL, NULL, 0}, /* traces 7 */
+{0, 0, NULL, NULL, NULL, NULL, 0, NULL, NULL}, /* traces 9 */
 0, /* hier_max_level 8 */
+0, /* timestart_from_savefile */
+0, /* timestart_from_savefile_valid */
 
 
 /*
@@ -177,6 +179,7 @@ NULL, /* base_or_curtime_label_currenttime_c_1 60 */
 ~0, /* display_grid 65 */
 1, /* time_scale 66 */
 'n', /* time_dimension 67 */
+0,   /* scale_to_time_dimension */
 0, /* maxtimewid_currenttime_c_1 69 */
 0, /* curtimewid_currenttime_c_1 70 */
 0, /* maxtext_currenttime_c_1 71 */
@@ -203,6 +206,17 @@ NULL, /* entrybox_text 82 */
 0, /* cleanup_entry_c_1 83 */
 
 
+/* 
+ * extload.c 
+ */
+NULL, /* extload */
+NULL, /* extload_idcodes */
+NULL, /* extload_inv_idcodes */
+#if !defined __MINGW32__ && !defined _MSC_VER
+0, /* extload_lastmod */
+0, /* extload_already_errored */
+#endif
+
 /*
  * fetchbuttons.c
  */
@@ -383,7 +397,7 @@ NULL, /* dict_string_mem_array_lxt_c_1 181 */
 0, /* exclude_offset_lxt_c_1 182 */
 NULL, /* lt_buf_lxt_c_1 183 */
 0, /* lt_len_lxt_c_1 184 */
-0, /* fd_lxt_c_1 185 */
+-1, /* fd_lxt_c_1 185 */
 {0,0,0,0,0,0,0,0}, /* double_mask_lxt_c_1 186 */
 0, /* double_is_native_lxt_c_1 187 */
 0, /* max_compare_time_tc_lxt_c_2 189 */
@@ -393,6 +407,14 @@ NULL, /* lt_buf_lxt_c_1 183 */
 /* 
  * main.c
  */
+NULL, /* argvlist */
+#if defined(HAVE_LIBTCL)
+NULL, /* interp */
+#endif
+NULL, /* repscript_name */
+500, /* repscript_period */
+0, /* tcl_running */
+0, /* block_xy_update */
 NULL, /* winname */
 0, /* num_notebook_pages */
 1, /* num_notebook_pages_cumulative */
@@ -464,11 +486,14 @@ NULL, /* window_markerbox_c_4 231 */
 NULL, /* cleanup_markerbox_c_4 233 */
 0, /* dirty_markerbox_c_1 234 */
 {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, /* shadow_markers_markerbox_c_1 235 */
+{NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL}, /* marker_names */
+{NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL}, /* shadow_marker_names */
 
 
 /*
  * menu.c
  */ 
+NULL, /* cutcopylist */
 0, /* enable_fast_exit 236 */
 NULL, /* script_handle 237 */
 0, /* ignore_savefile_pos 238 */
@@ -479,10 +504,12 @@ NULL, /* trace_to_alias_menu_c_1 243 */
 NULL, /* showchangeall_menu_c_1 244 */
 NULL, /* filesel_newviewer_menu_c_1 245 */
 NULL, /* filesel_logfile_menu_c_1 246 */
+NULL, /* filesel_scriptfile_menu */
 NULL, /* filesel_writesave 247 */
 0, /* save_success_menu_c_1 248 */
 NULL, /* filesel_vcd_writesave 249 */
 NULL, /* filesel_lxt_writesave 250 */
+NULL, /* filesel_tim_writesave */
 0, /* lock_menu_c_1 251 */
 0, /* lock_menu_c_2 252 */
 NULL, /* buf_menu_c_1 253 128 */
@@ -650,6 +677,7 @@ NULL, /* signalpixmap 371 */
 0, /* old_signal_fill_height */
 1, /* fontheight 376 */
 0, /* dnd_state 377 */
+0, /* dnd_cursor_timer */
 NULL, /* hscroll_signalwindow_c_1 378 */
 NULL, /* signal_hslider 379 */
 0, /* cachedhiflag_signalwindow_c_1 380 */
@@ -665,6 +693,9 @@ NULL, /* starting_unshifted_trace */
 0, /* signalarea_has_focus */
 NULL, /* signalarea_event_box */
 0, /* keypress_handler_id */
+0, /* cached_mouseover_x */
+0, /* cached_mouseover_y */
+0, /* mouseover_counter */
 
 /*
  * simplereq.c
@@ -791,6 +822,8 @@ NULL, /* void (*cleanup_treesearch_gtk1_c)(); */
 /*
  * treesearch_gtk2.c
  */
+NULL, /* treeopen_chain_head */
+NULL, /* treeopen_chain_curr */
 0, /* tree_dnd_begin */
 0, /* tree_dnd_requested */
 1, /* do_dynamic_treefilter */
@@ -1000,6 +1033,7 @@ NULL, /* mvlfacs_vzt_c_3 587 */
 /*
  * wavewindow.c
  */
+0, /* use_scrollwheel_as_y */
 0, /* m1x_wavewindow_c_1 589 */
 0, /* m2x */
 1, /* signalwindow_width_dirty 590 */
@@ -1017,6 +1051,8 @@ NULL, /* mvlfacs_vzt_c_3 587 */
 0, /* in_button_press_wavewindow_c_1 601 */
 0, /* left_justify_sigs 602 */
 0, /* zoom_pow10_snap 603 */
+0, /* zoom_dyn */
+0, /* zoom_dyne */
 0, /* cursor_snap 604 */
 -1.0, /* old_wvalue 605 */
 NULL, /* blackout_regions 606 */
@@ -1257,6 +1293,21 @@ void reload_into_new_context(void)
  new_globals = initialize_globals();
  free(new_globals->gtk_context_bridge_ptr); /* don't need this one as we're copying over the old one... */
  new_globals->gtk_context_bridge_ptr = GLOBALS->gtk_context_bridge_ptr;
+
+ /* SMP */
+ new_globals->num_cpus = GLOBALS->num_cpus;
+
+ /* tcl interpreter */
+#if defined(HAVE_LIBTCL)
+ new_globals->interp = GLOBALS->interp;
+#endif
+
+ /* lxt.c */
+ if(GLOBALS->fd_lxt_c_1 >= 0)
+	{
+	close(GLOBALS->fd_lxt_c_1);
+	GLOBALS->fd_lxt_c_1 = -1;
+	}
  
  /* Marker positions */
  memcpy(new_globals->named_markers, GLOBALS->named_markers, sizeof(GLOBALS->named_markers));
@@ -1271,6 +1322,14 @@ void reload_into_new_context(void)
  (*new_globals->contexts)[new_globals->this_context_page] = new_globals;
  new_globals->dead_context = GLOBALS->dead_context; /* this value is a ** chameleon!  malloc'd region is outside debug.c control! */
 
+ /* to cut down on temporary visual noise from incorrect zoom factor on reload */
+ new_globals->pixelsperframe = GLOBALS->pixelsperframe;
+ new_globals->nsperframe = GLOBALS->nsperframe;
+ new_globals->pxns = GLOBALS->pxns;
+ new_globals->nspx = GLOBALS->nspx;
+ new_globals->nspx = GLOBALS->nspx;
+ new_globals->zoom = GLOBALS->zoom;
+
  /* Default colors, X contexts, pixmaps, drawables, etc from signalwindow.c and wavewindow.c */
  new_globals->signalarea_event_box = GLOBALS->signalarea_event_box;
  new_globals->keypress_handler_id = GLOBALS->keypress_handler_id;
@@ -1407,6 +1466,10 @@ void reload_into_new_context(void)
  new_globals->wave_alert_pixmap = GLOBALS->wave_alert_pixmap;
 
  /* rc.c */
+ new_globals->scale_to_time_dimension = GLOBALS->scale_to_time_dimension;
+ new_globals->zoom_dyn = GLOBALS->zoom_dyn;
+ new_globals->zoom_dyne = GLOBALS->zoom_dyne;
+ new_globals->use_scrollwheel_as_y = GLOBALS->use_scrollwheel_as_y;
  new_globals->context_tabposition = GLOBALS->context_tabposition;
  new_globals->use_standard_clicking = GLOBALS->use_standard_clicking;
 
@@ -1501,9 +1564,13 @@ void reload_into_new_context(void)
 
  new_globals->logfiles = GLOBALS->logfiles; /* this value is a ** chameleon!  malloc'd region is outside debug.c control! */
 
+ strcpy2_into_new_context(new_globals, &new_globals->argvlist, &GLOBALS->argvlist);
  strcpy2_into_new_context(new_globals, &new_globals->fontname_logfile, &GLOBALS->fontname_logfile);
  strcpy2_into_new_context(new_globals, &new_globals->fontname_signals, &GLOBALS->fontname_signals); 
  strcpy2_into_new_context(new_globals, &new_globals->fontname_waves, &GLOBALS->fontname_waves);
+ strcpy2_into_new_context(new_globals, &new_globals->cutcopylist, &GLOBALS->cutcopylist);
+ strcpy2_into_new_context(new_globals, &new_globals->repscript_name, &GLOBALS->repscript_name);
+ new_globals->repscript_period = GLOBALS->repscript_period;
 
  /* hierarchy handling from vcd.c */
  if(GLOBALS->hier_pfx) { jrb_free_tree(GLOBALS->hier_pfx); GLOBALS->hier_pfx = NULL; }
@@ -1535,6 +1602,10 @@ void reload_into_new_context(void)
  new_globals->save_success_menu_c_1 = GLOBALS->save_success_menu_c_1; 
  new_globals->signal_popup_menu = GLOBALS->signal_popup_menu;
 
+ strcpy2_into_new_context(new_globals, &new_globals->filesel_vcd_writesave, &GLOBALS->filesel_vcd_writesave);
+ strcpy2_into_new_context(new_globals, &new_globals->filesel_lxt_writesave, &GLOBALS->filesel_lxt_writesave);
+ strcpy2_into_new_context(new_globals, &new_globals->filesel_tim_writesave, &GLOBALS->filesel_tim_writesave);
+
  /* status.c */
  new_globals->text_status_c_2 = GLOBALS->text_status_c_2;
 #if defined(WAVE_USE_GTK2) && !defined(GTK_ENABLE_BROKEN)
@@ -1606,7 +1677,11 @@ void reload_into_new_context(void)
    case NO_FILE:
    case GHW_FILE:
    case VCD_FILE:
-   case VCD_RECODER_FILE: /* do nothing */ break;
+   case VCD_RECODER_FILE: 
+#ifdef EXTLOAD_SUFFIX
+   case EXTLOAD_FILE:
+#endif
+	/* do nothing */ break;
  }
 
 
@@ -1749,6 +1824,15 @@ void reload_into_new_context(void)
 	/* Load new file from disk, no reload on partial vcd or vcd from stdin. */
 	switch(GLOBALS->loaded_file_type) 
 		{
+#ifdef EXTLOAD_SUFFIX   
+   		case EXTLOAD_FILE: 
+			extload_main(GLOBALS->loaded_file_name, GLOBALS->skip_start, GLOBALS->skip_end);
+			load_was_success = (GLOBALS->extload != NULL) && (!GLOBALS->extload_already_errored);
+			GLOBALS->extload_already_errored = 0;
+			GLOBALS->extload_lastmod = 0;
+			break;
+#endif
+
    		case LX2_FILE: 
 			lx2_main(GLOBALS->loaded_file_name,GLOBALS->skip_start,GLOBALS->skip_end);
 			load_was_success = (GLOBALS->lx2_lx2_c_1 != NULL);
@@ -1907,12 +1991,12 @@ void reload_into_new_context(void)
    gtk_widget_show(GLOBALS->expanderwindow);
    if(GLOBALS->dnd_sigview)
         {
-	dnd_setup(GLOBALS->dnd_sigview, GLOBALS->signalarea);
+	dnd_setup(GLOBALS->dnd_sigview, GLOBALS->signalarea, 0);
 	}
 
    if(GLOBALS->clist_search_c_3)
 	{
-	dnd_setup(GLOBALS->clist_search_c_3, GLOBALS->signalarea);
+	dnd_setup(GLOBALS->clist_search_c_3, GLOBALS->signalarea, 0);
 	}
  }
  #endif
@@ -2105,7 +2189,11 @@ void free_and_destroy_page_context(void)
    case NO_FILE:
    case GHW_FILE:
    case VCD_FILE:
-   case VCD_RECODER_FILE: /* do nothing */ break;
+   case VCD_RECODER_FILE: 
+#ifdef EXTLOAD_SUFFIX   
+   case EXTLOAD_FILE:
+#endif          
+	/* do nothing */ break;
  }
 
  /* window destruction (of windows that aren't the parent window) */
