@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Kermin Elliott Fleming 2007-2008.
+ * Copyright (c) Kermin Elliott Fleming 2007-2009.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -18,41 +18,43 @@
 #include <io.h>
 #endif
 
-#include"ae2.h"
-#include"analyzer.h"
-#include"bsearch.h"
-#include"busy.h"
-#include"clipping.h"
-#include"color.h"
-#include"currenttime.h"
-#include"debug.h"
-#include"fgetdynamic.h"
-#include"fonts.h"
-#include"ghw.h"
-#include"globals.h"
-#include"gnu_regex.h"
-#include"gtk12compat.h"
-#include"lx2.h"
-#include"lxt.h"
-#include"main.h"
-#include"memory.h"
-#include"menu.h"
-#include"pipeio.h"
-#include"pixmaps.h"
-#include"print.h"
-#include"ptranslate.h"
-#include"rc.h"
-#include"regex_wave.h"
-#include"strace.h"
-#include"symbol.h"
-#include"translate.h"
-#include"tree.h"
-#include"vcd.h"
-#include"vcd_saver.h"
-#include"vlist.h" 
-#include"vzt.h"
-#include"wavealloca.h"
-#include"jrb.h"
+#include "ae2.h"
+#include "analyzer.h"
+#include "bsearch.h"
+#include "busy.h"
+#include "clipping.h"
+#include "color.h"
+#include "currenttime.h"
+#include "debug.h"
+#include "fgetdynamic.h"
+#include "fonts.h"
+#include "ghw.h"
+#include "globals.h"
+#include "gnu_regex.h"
+#include "gtk12compat.h"
+#include "lx2.h"
+#include "lxt.h"
+#include "main.h"
+#include "memory.h"
+#include "menu.h"
+#include "pipeio.h"
+#include "pixmaps.h"
+#include "print.h"
+#include "ptranslate.h"
+#include "rc.h"
+#include "regex_wave.h"
+#include "strace.h"
+#include "symbol.h"
+#include "tcl_helper.h"
+#include "translate.h"
+#include "tree.h"
+#include "vcd.h"
+#include "vcd_saver.h"
+#include "vlist.h" 
+#include "vzt.h"
+#include "wavealloca.h"
+#include "jrb.h"
+#include "extload.h"
 
 struct Global{ 
 
@@ -87,7 +89,8 @@ unsigned int default_flags; /* from analyzer.c 5 */
 Times tims; /* from analyzer.c 6 */
 Traces traces; /* from analyzer.c 7 */
 int hier_max_level; /* from analyzer.c 8 */
-
+TimeType timestart_from_savefile;
+char timestart_from_savefile_valid;
 
 /*
  * baseconvert.c
@@ -172,6 +175,7 @@ TimeType min_time; /* from currenttime.c 65 */
 char display_grid; /* from currenttime.c 66 */
 TimeType time_scale; /* from currenttime.c 67 */
 char time_dimension; /* from currenttime.c 68 */
+char scale_to_time_dimension; /* from currenttime.c */
 GtkWidget *maxtimewid_currenttime_c_1; /* from currenttime.c 70 */
 GtkWidget *curtimewid_currenttime_c_1; /* from currenttime.c 71 */
 char *maxtext_currenttime_c_1; /* from currenttime.c 72 */
@@ -198,6 +202,16 @@ char *entrybox_text; /* from entry.c 83 */
 void (*cleanup_entry_c_1)(); /* from entry.c 84 */
 
 
+/* extload.c */
+FILE *extload; /* from extload.c */
+unsigned int *extload_idcodes; /* from extload.c */
+int *extload_inv_idcodes; /* from extload.c */
+#if !defined __MINGW32__ && !defined _MSC_VER
+time_t extload_lastmod; /* from extload.c */
+char extload_already_errored; /* from extload.c */
+#endif
+
+
 /*
  * fetchbuttons.c
  */
@@ -389,6 +403,14 @@ int max_compare_pos_tc_lxt_c_2; /* from lxt.c 200 */
 /*
  * main.c
  */
+char *argvlist;
+#ifdef HAVE_LIBTCL
+Tcl_Interp *interp;
+#endif
+char *repscript_name;
+unsigned int repscript_period;
+char tcl_running;
+char block_xy_update;
 char *winname;
 unsigned int num_notebook_pages;
 unsigned int num_notebook_pages_cumulative;
@@ -457,11 +479,13 @@ GtkWidget *entries_markerbox_c_1[26]; /* from markerbox.c 249 */
 void (*cleanup_markerbox_c_4)(); /* from markerbox.c 250 */
 int dirty_markerbox_c_1; /* from markerbox.c 251 */
 TimeType shadow_markers_markerbox_c_1[26]; /* from markerbox.c 252 */
-
+char *marker_names[26]; /* from markerbox.c */
+char *shadow_marker_names[26]; /* from markerbox.c */
 
 /*
  * menu.c
  */
+char *cutcopylist; /* from menu.c */
 char enable_fast_exit; /* from menu.c 253 */
 FILE *script_handle; /* from menu.c 254 */
 char ignore_savefile_pos; /* from menu.c 255 */
@@ -472,10 +496,12 @@ struct TraceEnt *trace_to_alias_menu_c_1; /* from menu.c 260 */
 struct TraceEnt *showchangeall_menu_c_1; /* from menu.c 261 */
 char *filesel_newviewer_menu_c_1; /* from menu.c 262 */
 char *filesel_logfile_menu_c_1; /* from menu.c 263 */
+char *filesel_scriptfile_menu; /* from menu.c */
 char *filesel_writesave; /* from menu.c 264 */
 char save_success_menu_c_1; /* from menu.c 265 */
 char *filesel_vcd_writesave; /* from menu.c 266 */
 char *filesel_lxt_writesave; /* from menu.c 267 */
+char *filesel_tim_writesave; /* from menu.c */
 int lock_menu_c_1; /* from menu.c 268 */
 int lock_menu_c_2; /* from menu.c 269 */
 char *buf_menu_c_1; /* from menu.c 270 */
@@ -644,6 +670,7 @@ int old_signal_fill_width; /* from signalwindow.c 402 */
 int old_signal_fill_height; /* from signalwindow.c 403 */
 int fontheight; /* from signalwindow.c 404 */
 char dnd_state; /* from signalwindow.c 405 */
+unsigned int dnd_cursor_timer; /* from signalwindow.c */
 GtkWidget *hscroll_signalwindow_c_1; /* from signalwindow.c 406 */
 GtkObject *signal_hslider; /* from signalwindow.c 407 */
 unsigned int cachedhiflag_signalwindow_c_1; /* from signalwindow.c 408 */
@@ -659,6 +686,9 @@ unsigned char std_dnd_tgt_on_wavearea; /* from signalwindow.c */
 unsigned char signalarea_has_focus; /* from signalwindow.c */
 GtkWidget *signalarea_event_box; /* from signalwindow.c */
 gint keypress_handler_id; /* from signalwindow.c */
+gint cached_mouseover_x; /* from signalwindow.c */
+gint cached_mouseover_y; /* from signalwindow.c */
+gint mouseover_counter; /* from signalwindow.c */
 
 
 /*
@@ -786,6 +816,8 @@ void (*cleanup_treesearch_gtk1_c)(); /* ...end of manual adds */
 /*
  * treesearch_gtk2.c
  */
+struct string_chain_t *treeopen_chain_head; /* from bitvec.c */
+struct string_chain_t *treeopen_chain_curr; /* from bitvec.c */
 char tree_dnd_begin; /* from treesearch_gtk2.c */
 char tree_dnd_requested; /* from treesearch_gtk2.c */
 char do_dynamic_treefilter; /* from treesearch_gtk2.c */
@@ -995,6 +1027,7 @@ int busycnt_vzt_c_2; /* from vzt.c 641 */
 /*
  * wavewindow.c
  */
+char use_scrollwheel_as_y; /* fromwavewindow.c */
 int m1x_wavewindow_c_1; /* from wavewindow.c 642 */
 int m2x_wavewindow_c_1; /* from wavewindow.c 643 */
 char signalwindow_width_dirty; /* from wavewindow.c 644 */
@@ -1012,6 +1045,8 @@ int vector_padding; /* from wavewindow.c 655 */
 int in_button_press_wavewindow_c_1; /* from wavewindow.c 656 */
 char left_justify_sigs; /* from wavewindow.c 657 */
 char zoom_pow10_snap; /* from wavewindow.c 658 */
+char zoom_dyn; /* from menu.c */
+char zoom_dyne; /* from menu.c */
 int cursor_snap; /* from wavewindow.c 659 */
 float old_wvalue; /* from wavewindow.c 660 */
 struct blackout_region_t *blackout_regions; /* from wavewindow.c 661 */
