@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2004 Tony Bybell.
+ * Copyright (c) 2003-2008 Tony Bybell.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -57,9 +57,11 @@ _LXT2_RD_INLINE static unsigned int lxt2_rd_get_16(void *mm, int offset)
 {
 unsigned short x = *((unsigned short *)((unsigned char *)mm+offset));
 
-  __asm("xchgb %b0,%h0" :
-        "=q" (x)        :
-        "0" (x));
+#if defined(__i386__)
+    __asm("xchgb %b0,%h0" : "=q" (x) : "0" (x));
+#else
+    __asm("xchgb %b0,%h0" : "=Q" (x) : "0" (x));
+#endif
 
     return (unsigned int) x;
 }
@@ -1478,8 +1480,6 @@ if(lt)
 		{
 		if((!b->mem)&&(!b->short_read_ignore)&&(!b->exclude_block))
 			{
-			int rc;
-
 			if(processed<5)
 				{
 				int gate = (processed==4) && b->next;
@@ -1566,6 +1566,8 @@ if(lt)
 				}
 				else
 				{
+				int rc;
+
 				b->mem = malloc(b->uncompressed_siz);
 				lt->zhandle = gzdopen(dup(fileno(lt->handle)), "rb");
 				rc=gzread(lt->zhandle, b->mem, b->uncompressed_siz);
@@ -1727,8 +1729,14 @@ return(blk);
 }
 
 /*
- * $Id: lxt2_read.c,v 1.1.1.1 2007/05/30 04:28:17 gtkwave Exp $
+ * $Id: lxt2_read.c,v 1.3 2008/12/20 05:08:26 gtkwave Exp $
  * $Log: lxt2_read.c,v $
+ * Revision 1.3  2008/12/20 05:08:26  gtkwave
+ * -Wshadow warning cleanups
+ *
+ * Revision 1.2  2008/11/13 22:52:25  gtkwave
+ * x86_64 fix on xchgb
+ *
  * Revision 1.1.1.1  2007/05/30 04:28:17  gtkwave
  * Imported sources
  *
