@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2008.
+ * Copyright (c) Tony Bybell 1999-2009.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -65,6 +65,8 @@
 #include "translate.h"
 #include "ptranslate.h"
 
+#include "tcl_helper.h"
+
 static void switch_page(GtkNotebook     *notebook,
 			GtkNotebookPage *page,
 			guint            page_num,
@@ -85,11 +87,14 @@ GLOBALS->constant_marker_update = g_old->constant_marker_update;
 GLOBALS->do_zoom_center = g_old->do_zoom_center;
 GLOBALS->use_roundcaps = g_old->use_roundcaps;
 GLOBALS->do_resize_signals = g_old->do_resize_signals;
+GLOBALS->scale_to_time_dimension = g_old->scale_to_time_dimension;
 GLOBALS->use_full_precision = g_old->use_full_precision;
 GLOBALS->show_base = g_old->show_base;
 GLOBALS->display_grid = g_old->display_grid;
 GLOBALS->disable_mouseover = g_old->disable_mouseover;
 GLOBALS->zoom_pow10_snap = g_old->zoom_pow10_snap;
+GLOBALS->zoom_dyn = g_old->zoom_dyn;
+GLOBALS->zoom_dyne = g_old->zoom_dyne;
 
 reformat_time(timestr, GLOBALS->tims.first, GLOBALS->time_dimension);
 gtk_entry_set_text(GTK_ENTRY(GLOBALS->from_entry),timestr);
@@ -170,13 +175,25 @@ static void print_help(char *nam)
 #define INTR_GETOPT
 #endif
 
-
 #ifdef WAVE_USE_XID
 #define XID_GETOPT 	 "  -X, --xid=XID              specify XID of window for GtkPlug to connect to\n"
 #else
 #define XID_GETOPT
 #endif
 
+#if defined(HAVE_LIBTCL)
+#define REPSCRIPT_GETOPT "  -R, --repscript=FILE       specify timer-driven Tcl command script file\n"\
+                         "  -P, --repperiod=VALUE      specify repscript period in msec (default: 500)\n"
+#else
+#define REPSCRIPT_GETOPT
+#endif
+
+#if !defined _MSC_VER && !defined __MINGW32__
+#define OUTPUT_GETOPT "  -O, --output=FILE          specify filename for stdout/stderr redirect\n"
+#else
+#define OUTPUT_GETOPT
+#endif
+
 printf(
 "Usage: %s [OPTION]... [DUMPFILE] [SAVEFILE] [RCFILE]\n\n"
 "  -n, --nocli=DIRPATH        use file requester for dumpfile name\n"
@@ -196,12 +213,14 @@ WAVE_GETOPT_CPUS
 "  -N, --nowm                 disable window manager for most windows\n"
 "  -M, --nomenus              do not render menubar (for making applets)\n"
 "  -S, --script=FILE          specify GUI command script file for execution\n"
+REPSCRIPT_GETOPT
 XID_GETOPT
 INTR_GETOPT
 "  -C, --comphier             use compressed hierarchy names (slower)\n"
 "  -g, --giga                 use gigabyte mempacking when recoding (slower)\n"
 "  -L, --legacy               use legacy VCD mode rather than the VCD recoder\n" 
 "  -v, --vcd                  use stdin as a VCD dumpfile\n"
+OUTPUT_GETOPT
 "  -V, --version              display version banner then exit\n"
 "  -h, --help                 display this help then exit\n"
 "  -x, --exit                 exit after loading trace (for loader benchmarks)\n\n"
@@ -260,6 +279,7 @@ int main_2(int argc, char *argv[])
 static char *winprefix="GTKWave - ";
 static char *winstd="GTKWave (stdio) ";
 static char *vcd_autosave_name="vcd_autosave.sav";
+char *output_name = NULL;
 
 int i;
 int c;
@@ -291,6 +311,7 @@ GtkWidget *timebox;
 GtkWidget *panedwindow;
 GtkWidget *dummy1, *dummy2;
 GtkWidget *toolhandle=NULL;
+int tcl_interpreter_needs_making = 0;
 
 int splash_disable_rc_override = 0;
 int mainwindow_already_built;
@@ -304,6 +325,7 @@ if(!GLOBALS)
 	mainwindow_already_built = 0;
 
 	GLOBALS->logfiles = calloc(1, sizeof(void **)); /* calloc is deliberate! */
+	tcl_interpreter_needs_making = 1;
 	}
 	else
 	{
@@ -328,6 +350,9 @@ if(!GLOBALS)
 	GLOBALS->logfiles = old_g->logfiles;
 
 	/* menu.c */
+#if defined(HAVE_LIBTCL)
+	GLOBALS->interp = old_g->interp;
+#endif
 	GLOBALS->item_factory_menu_c_1 = old_g->item_factory_menu_c_1;
 	GLOBALS->vcd_jmp_buf = old_g->vcd_jmp_buf;
 
@@ -397,6 +422,7 @@ if(!GLOBALS)
 	GLOBALS->disable_tooltips = old_g->disable_tooltips;
 	GLOBALS->do_initial_zoom_fit = old_g->do_initial_zoom_fit;
 	GLOBALS->do_resize_signals = old_g->do_resize_signals;
+	GLOBALS->scale_to_time_dimension = old_g->scale_to_time_dimension;
 	GLOBALS->enable_fast_exit = old_g->enable_fast_exit;
 	GLOBALS->enable_ghost_marker = old_g->enable_ghost_marker;
 	GLOBALS->enable_horiz_grid = old_g->enable_horiz_grid;
@@ -428,6 +454,8 @@ if(!GLOBALS)
 	GLOBALS->wave_scrolling = old_g->wave_scrolling;
 	GLOBALS->do_zoom_center = old_g->do_zoom_center;
 	GLOBALS->zoom_pow10_snap = old_g->zoom_pow10_snap;
+	GLOBALS->zoom_dyn = old_g->zoom_dyn;
+	GLOBALS->zoom_dyne = old_g->zoom_dyne;
 	GLOBALS->alt_hier_delimeter = old_g->alt_hier_delimeter;
 	GLOBALS->cursor_snap = old_g->cursor_snap;
 	GLOBALS->hier_delimeter = old_g->hier_delimeter;
@@ -449,6 +477,7 @@ if(!GLOBALS)
 	strcpy2_into_new_context(GLOBALS, &GLOBALS->fontname_logfile, &old_g->fontname_logfile);
 	strcpy2_into_new_context(GLOBALS, &GLOBALS->fontname_signals, &old_g->fontname_signals); 
 	strcpy2_into_new_context(GLOBALS, &GLOBALS->fontname_waves, &old_g->fontname_waves);
+        strcpy2_into_new_context(GLOBALS, &GLOBALS->argvlist, &old_g->argvlist);
 
 	mainwindow_already_built = 1;
 	}
@@ -458,6 +487,9 @@ strcpy(GLOBALS->whoami, argv[0]);
 
 if(!mainwindow_already_built)
 	{
+#ifdef __MINGW32__
+	gtk_disable_setlocale();
+#endif
 	if(!gtk_init_check(&argc, &argv))
 		{
 		printf("Could not initialize GTK!  Is DISPLAY env var/xhost set?\n\n");
@@ -506,10 +538,13 @@ while (1)
 		{"giga", 0, 0, 'g'},
 		{"comphier", 0, 0, 'C'},
                 {"legacy", 0, 0, 'L'},  
+		{"repscript", 1, 0, 'R'},
+		{"repperiod", 1, 0, 'P'},
+		{"output", 1, 0, 'O' },
                 {0, 0, 0, 0}
                 };
 
-        c = getopt_long (argc, argv, "f:on:a:Ar:di:l:s:e:c:t:NS:vVhxX:MD:IgCL", long_options, &option_index);
+        c = getopt_long (argc, argv, "f:on:a:Ar:di:l:s:e:c:t:NS:vVhxX:MD:IgCLR:P:O:", long_options, &option_index);
 
         if (c == -1) break;     /* no more args */
 
@@ -712,6 +747,28 @@ while (1)
 			GLOBALS->do_hier_compress = 1;
 			break;
 
+                case 'R':
+			if(GLOBALS->repscript_name) free_2(GLOBALS->repscript_name);
+			GLOBALS->repscript_name = malloc_2(strlen(optarg)+1);
+			strcpy(GLOBALS->repscript_name, optarg);
+			break;
+
+                case 'O':
+			if(output_name) free_2(output_name);
+			output_name = malloc_2(strlen(optarg)+1);
+			strcpy(output_name, optarg);
+			break;
+
+                case 'P':
+			{
+			int pd = atoi(optarg);
+			if(pd > 0)
+				{
+				GLOBALS->repscript_period = pd;	
+				}
+			}
+			break;
+
                 case '?':
 			opt_errors_encountered=1;
                         break;
@@ -731,6 +788,14 @@ if (optind < argc)
         {
         while (optind < argc)
 		{
+                if(argv[optind][0] == '-')
+                        {
+                        if(!strcmp(argv[optind], "--"))
+                                {
+                                break;
+                                }
+                        }   
+
 		if(!GLOBALS->loaded_file_name)
 			{
 			is_vcd = 0;
@@ -764,7 +829,45 @@ if(is_giga)
 	GLOBALS->vlist_prepack = 1;
 	}
 
+if(output_name)
+	{
+#if !defined _MSC_VER && !defined __MINGW32__
+	int iarg;
+	time_t walltime;
+	int fd_replace = open(output_name, O_CREAT|O_WRONLY|O_TRUNC, S_IRUSR|S_IWUSR);
+	if(fd_replace<0)
+		{
+		fprintf(stderr, "Could not open redirect file, exiting.\n");
+		perror("Why");
+		exit(255);
+		}
+
+	dup2(fd_replace, 1);
+	dup2(fd_replace, 2);
+
+        time(&walltime);
+        printf(WAVE_VERSION_INFO"\nDate: %s\n\n",asctime(localtime(&walltime)));
+
+	for(iarg=0;iarg<argc;iarg++)
+		{
+		if(iarg) printf("\t");
+		printf("%s\n", argv[iarg]);
+		}
+
+	printf("\n\n");
+	fflush(stdout);
+
+#endif
+	free_2(output_name);
+	output_name = NULL;
+	}
+
 fprintf(stderr, "\n%s\n\n",WAVE_VERSION_INFO);
+if(tcl_interpreter_needs_making)
+	{
+	GLOBALS->argvlist = zMergeTclList(argc, (const char**)argv);
+	make_tcl_interpreter(argv);
+	}
 
 if((!wname)&&(GLOBALS->make_vcd_save_file))
 	{
@@ -800,6 +903,22 @@ strcat(GLOBALS->winname,GLOBALS->loaded_file_name);
 
 loader_check_head:
 
+#ifdef EXTLOAD_SUFFIX
+if( (strlen(GLOBALS->loaded_file_name)>strlen(EXTLOAD_SUFFIX))&&
+	((!strcasecmp(GLOBALS->loaded_file_name+strlen(GLOBALS->loaded_file_name)-strlen(EXTLOAD_SUFFIX),EXTLOAD_SUFFIX))) )
+	{
+	TimeType extload_max;
+
+	GLOBALS->loaded_file_type = EXTLOAD_FILE;
+	extload_max = extload_main(GLOBALS->loaded_file_name, GLOBALS->skip_start, GLOBALS->skip_end);
+	if((!GLOBALS->extload) || (GLOBALS->extload_already_errored) || (!extload_max))
+		{
+		fprintf(stderr, "Could not initialize '%s', exiting.\n", GLOBALS->loaded_file_name);
+		exit(255);
+		}
+	}
+else
+#endif
 if((strlen(GLOBALS->loaded_file_name)>3)&&((!strcasecmp(GLOBALS->loaded_file_name+strlen(GLOBALS->loaded_file_name)-4,".lxt"))||(!strcasecmp(GLOBALS->loaded_file_name+strlen(GLOBALS->loaded_file_name)-4,".lx2"))))
 	{
 	FILE *f = fopen(GLOBALS->loaded_file_name, "rb");
@@ -1113,12 +1232,15 @@ if(!GLOBALS->socket_xid)
         {
 	GLOBALS->mainwindow = gtk_window_new(GLOBALS->disable_window_manager ? GTK_WINDOW_POPUP : GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title(GTK_WINDOW(GLOBALS->mainwindow), GLOBALS->winname);
-	gtk_widget_set_usize(GTK_WIDGET(GLOBALS->mainwindow), GLOBALS->initial_window_x, GLOBALS->initial_window_y);
 
 	if((GLOBALS->initial_window_width>0)&&(GLOBALS->initial_window_height>0))
 		{
 		gtk_window_set_default_size(GTK_WINDOW (GLOBALS->mainwindow), GLOBALS->initial_window_width, GLOBALS->initial_window_height);
 		}
+		else
+		{
+		gtk_window_set_default_size(GTK_WINDOW(GLOBALS->mainwindow), GLOBALS->initial_window_x, GLOBALS->initial_window_y);
+		}
 
 	gtk_signal_connect(GTK_OBJECT(GLOBALS->mainwindow), "delete_event", 	/* formerly was "destroy" */GTK_SIGNAL_FUNC(file_quit_cmd_callback), "WM destroy");
 
@@ -1143,6 +1265,7 @@ if(GLOBALS->use_toolbutton_interface)
 	{
 	GtkWidget *tb;
 	GtkWidget *stock;
+	GtkStyle *style;
 	int tb_pos;
 
 	if(!mainwindow_already_built)
@@ -1192,6 +1315,21 @@ if(GLOBALS->use_toolbutton_interface)
 						 GTK_SIGNAL_FUNC(menu_cut_traces),
 						 NULL,
 						 tb_pos++);
+		style = gtk_widget_get_style(stock);
+		style->xthickness = style->ythickness = 0;
+		gtk_widget_set_style (stock, style);
+		gtk_widget_show(stock);
+
+		stock = gtk_toolbar_insert_stock(GTK_TOOLBAR(tb),
+	                                         GTK_STOCK_COPY,
+						 "Copy Traces",
+						 NULL,
+						 GTK_SIGNAL_FUNC(menu_copy_traces),
+						 NULL,
+						 tb_pos++);
+		style = gtk_widget_get_style(stock);
+		style->xthickness = style->ythickness = 0;
+		gtk_widget_set_style (stock, style);
 		gtk_widget_show(stock);
 
 		stock = gtk_toolbar_insert_stock(GTK_TOOLBAR(tb),
@@ -1201,6 +1339,9 @@ if(GLOBALS->use_toolbutton_interface)
 						 GTK_SIGNAL_FUNC(menu_paste_traces),
 						 NULL,
 						 tb_pos++);
+		style = gtk_widget_get_style(stock);
+		style->xthickness = style->ythickness = 0;
+		gtk_widget_set_style (stock, style);
 		gtk_widget_show(stock);
 
 		gtk_toolbar_insert_space(GTK_TOOLBAR(tb), tb_pos++);
@@ -1212,6 +1353,9 @@ if(GLOBALS->use_toolbutton_interface)
 						 GTK_SIGNAL_FUNC(service_zoom_fit),
 						 NULL,
 						 tb_pos++);
+		style = gtk_widget_get_style(stock);
+		style->xthickness = style->ythickness = 0;
+		gtk_widget_set_style (stock, style);
 		gtk_widget_show(stock);
 
 		stock = gtk_toolbar_insert_stock(GTK_TOOLBAR(tb),
@@ -1221,6 +1365,9 @@ if(GLOBALS->use_toolbutton_interface)
 						 GTK_SIGNAL_FUNC(service_zoom_in),
 						 NULL,
 						 tb_pos++);
+		style = gtk_widget_get_style(stock);
+		style->xthickness = style->ythickness = 0;
+		gtk_widget_set_style (stock, style);
 		gtk_widget_show(stock);
 
 		stock = gtk_toolbar_insert_stock(GTK_TOOLBAR(tb),
@@ -1230,6 +1377,9 @@ if(GLOBALS->use_toolbutton_interface)
 						 GTK_SIGNAL_FUNC(service_zoom_out),
 						 NULL,
 						 tb_pos++);
+		style = gtk_widget_get_style(stock);
+		style->xthickness = style->ythickness = 0;
+		gtk_widget_set_style (stock, style);
 		gtk_widget_show(stock);
 
 		stock = gtk_toolbar_insert_stock(GTK_TOOLBAR(tb),
@@ -1239,6 +1389,9 @@ if(GLOBALS->use_toolbutton_interface)
 						 GTK_SIGNAL_FUNC(service_zoom_undo),
 						 NULL,
 						 tb_pos++);
+		style = gtk_widget_get_style(stock);
+		style->xthickness = style->ythickness = 0;
+		gtk_widget_set_style (stock, style);
 		gtk_widget_show(stock);
 
 		stock = gtk_toolbar_insert_stock(GTK_TOOLBAR(tb),
@@ -1248,6 +1401,9 @@ if(GLOBALS->use_toolbutton_interface)
 						 GTK_SIGNAL_FUNC(service_zoom_left),
 						 NULL,
 						 tb_pos++);
+		style = gtk_widget_get_style(stock);
+		style->xthickness = style->ythickness = 0;
+		gtk_widget_set_style (stock, style);
 		gtk_widget_show(stock);
 
 		stock = gtk_toolbar_insert_stock(GTK_TOOLBAR(tb),
@@ -1257,6 +1413,9 @@ if(GLOBALS->use_toolbutton_interface)
 						 GTK_SIGNAL_FUNC(service_zoom_right),
 						 NULL,
 						 tb_pos++);
+		style = gtk_widget_get_style(stock);
+		style->xthickness = style->ythickness = 0;
+		gtk_widget_set_style (stock, style);
 		gtk_widget_show(stock);
 
 		gtk_toolbar_insert_space(GTK_TOOLBAR(tb), tb_pos++);
@@ -1268,6 +1427,9 @@ if(GLOBALS->use_toolbutton_interface)
 						 GTK_SIGNAL_FUNC(service_left_edge),
 						 NULL,
 						 tb_pos++);
+		style = gtk_widget_get_style(stock);
+		style->xthickness = style->ythickness = 0;
+		gtk_widget_set_style (stock, style);
 		gtk_widget_show(stock);
 
 		stock = gtk_toolbar_insert_stock(GTK_TOOLBAR(tb),
@@ -1277,6 +1439,9 @@ if(GLOBALS->use_toolbutton_interface)
 						 GTK_SIGNAL_FUNC(service_right_edge),
 						 NULL,
 						 tb_pos++);
+		style = gtk_widget_get_style(stock);
+		style->xthickness = style->ythickness = 0;
+		gtk_widget_set_style (stock, style);
 		gtk_widget_show(stock);
 
 		gtk_toolbar_insert_space(GTK_TOOLBAR(tb), tb_pos++);
@@ -1300,6 +1465,9 @@ if(GLOBALS->use_toolbutton_interface)
 						 GTK_SIGNAL_FUNC(menu_reload_waveform),
 						 NULL,
 						 tb_pos++);
+			style = gtk_widget_get_style(stock);
+			style->xthickness = style->ythickness = 0;
+			gtk_widget_set_style (stock, style);
 			gtk_widget_show(stock);
 
 			gtk_toolbar_insert_space(GTK_TOOLBAR(tb), tb_pos++);
@@ -1426,7 +1594,7 @@ if(GLOBALS->use_toolbutton_interface)
 		if((GLOBALS->loaded_file_type != NO_FILE)&&(!GLOBALS->disable_menus))
 			{
 			GtkWidget *r_pixmap = gtk_pixmap_new(GLOBALS->redo_pixmap, GLOBALS->redo_mask);
-			GtkWidget *main_vbox;
+			GtkWidget *main_vbox1;
 			GtkWidget *table, *table2;
 			GtkWidget *b1, *frame;
 			GtkTooltips *tooltips;
@@ -1438,15 +1606,15 @@ if(GLOBALS->use_toolbutton_interface)
 
 			table = gtk_table_new (1, 1, FALSE);
 		
-			main_vbox = gtk_vbox_new (FALSE, 1);
-			gtk_container_border_width (GTK_CONTAINER (main_vbox), 1);
-			gtk_container_add (GTK_CONTAINER (table), main_vbox);
+			main_vbox1 = gtk_vbox_new (FALSE, 1);
+			gtk_container_border_width (GTK_CONTAINER (main_vbox1), 1);
+			gtk_container_add (GTK_CONTAINER (table), main_vbox1);
 	
 			frame = gtk_frame_new ("Reload ");
-			gtk_box_pack_start (GTK_BOX (main_vbox), frame, TRUE, TRUE, 0);
+			gtk_box_pack_start (GTK_BOX (main_vbox1), frame, TRUE, TRUE, 0);
 	
 			gtk_widget_show (frame);
-			gtk_widget_show (main_vbox);
+			gtk_widget_show (main_vbox1);
 
 			table2 = gtk_table_new (2, 1, FALSE);
 	
@@ -1520,10 +1688,14 @@ gtk_widget_show(panedwindow);
 
 if(GLOBALS->dnd_sigview)
 	{
-	dnd_setup(GLOBALS->dnd_sigview, GLOBALS->signalarea);
+	dnd_setup(GLOBALS->dnd_sigview, GLOBALS->signalarea, 1);
 	}
-dnd_setup(GLOBALS->signalarea, GLOBALS->signalarea);
-dnd_setup(GLOBALS->signalarea, GLOBALS->wavearea);
+	else
+	{
+	dnd_setup(NULL, GLOBALS->signalarea, 1);
+	}
+/* dnd_setup(GLOBALS->signalarea, GLOBALS->signalarea); */
+dnd_setup(GLOBALS->signalarea, GLOBALS->wavearea, 1);
 
 #if GTK_CHECK_VERSION(2,4,0)
 if(!GLOBALS->hide_sst)
@@ -1534,6 +1706,28 @@ if(!GLOBALS->hide_sst)
 	}
 #endif
 
+#if WAVE_USE_GTK2
+if(GLOBALS->treeopen_chain_head)
+	{
+	struct string_chain_t *t = GLOBALS->treeopen_chain_head;
+	struct string_chain_t *t2;
+	while(t)
+		{
+		if(GLOBALS->ctree_main)
+			{
+			force_open_tree_node(t->str);
+			}
+
+		t2 = t;
+		if(t->str) free_2(t->str);
+		free_2(t);
+		t = t2->next;
+		}
+
+	GLOBALS->treeopen_chain_head = GLOBALS->treeopen_chain_curr = NULL;
+	}
+#endif
+
 if(!mainwindow_already_built)
 	{
 	gtk_widget_show(top_table);
@@ -1566,7 +1760,7 @@ if(!GLOBALS->notebook)
 	}
 	else
 	{
-	unsigned int i;
+	unsigned int ix;
 
 	GLOBALS->this_context_page = GLOBALS->num_notebook_pages;
 	GLOBALS->num_notebook_pages++;
@@ -1574,11 +1768,11 @@ if(!GLOBALS->notebook)
 	*GLOBALS->contexts = realloc(*GLOBALS->contexts, GLOBALS->num_notebook_pages * sizeof(struct Globals *)); /* realloc is deliberate! */
 	(*GLOBALS->contexts)[GLOBALS->this_context_page] = GLOBALS;
 
-	for(i=0;i<GLOBALS->num_notebook_pages;i++)
+	for(ix=0;ix<GLOBALS->num_notebook_pages;ix++)
 		{
-		(*GLOBALS->contexts)[i]->num_notebook_pages = GLOBALS->num_notebook_pages;
-		(*GLOBALS->contexts)[i]->num_notebook_pages_cumulative = GLOBALS->num_notebook_pages_cumulative;
-		(*GLOBALS->contexts)[i]->dead_context = (*GLOBALS->contexts)[0]->dead_context;	/* mirroring this is OK as page 0 always has value! */
+		(*GLOBALS->contexts)[ix]->num_notebook_pages = GLOBALS->num_notebook_pages;
+		(*GLOBALS->contexts)[ix]->num_notebook_pages_cumulative = GLOBALS->num_notebook_pages_cumulative;
+		(*GLOBALS->contexts)[ix]->dead_context = (*GLOBALS->contexts)[0]->dead_context;	/* mirroring this is OK as page 0 always has value! */
 		}
 
 	gtk_notebook_set_show_tabs(GTK_NOTEBOOK(GLOBALS->notebook), ~0); /* then appear */
@@ -1809,6 +2003,11 @@ get_window_size (int *x, int *y)
 void
 set_window_size (int x, int y)
 {
+  if(GLOBALS->block_xy_update)
+    {
+      return;
+    }
+
   if (GLOBALS->mainwindow == NULL)
     {
       GLOBALS->initial_window_width = x;
@@ -1888,8 +2087,8 @@ int stems_are_active(void)
 {
 if(GLOBALS->anno_ctx && GLOBALS->anno_ctx->browser_process)
 	{
-	int stat =0;
-	pid_t pid = waitpid(GLOBALS->anno_ctx->browser_process, &stat, WNOHANG);
+	int mystat =0;
+	pid_t pid = waitpid(GLOBALS->anno_ctx->browser_process, &mystat, WNOHANG);
 	if(!pid)
 		{
 		status_text("Stems reader already active.\n");
@@ -1906,6 +2105,7 @@ return(0);
 }
 #endif
 
+
 void activate_stems_reader(char *stems_name)
 {
 #if !defined _MSC_VER && !defined __MINGW32__
@@ -1922,8 +2122,19 @@ if(GLOBALS->stems_type != WAVE_ANNO_NONE)
 	{
 	if(!cyg_called)
 		{
-		fprintf(stderr, "GTKWAVE | If the viewer crashes with a Bad system call error,\n");
-		fprintf(stderr, "GTKWAVE | make sure that Cygserver is enabled.\n");
+		char *cygserver_env = getenv("CYGWIN");
+		gboolean found = cygserver_env && (strstr(cygserver_env, "server") != NULL);
+
+		if(!found)
+			{
+			fprintf(stderr, "GTKWAVE | =================================================================\n");
+			fprintf(stderr, "GTKWAVE | If the viewer crashes with a Bad system call error,\n");
+			fprintf(stderr, "GTKWAVE | make sure that Cygserver is enabled.\n");
+			fprintf(stderr, "GTKWAVE | The Cygserver services are used by Cygwin applications only\n");
+			fprintf(stderr, "GTKWAVE | if you set the environment variable CYGWIN to contain the\n");
+			fprintf(stderr, "GTKWAVE | string \"server\". You must do this before starting this program.\n");
+			fprintf(stderr, "GTKWAVE | =================================================================\n");
+			}
 		cyg_called = 1;
 		}
 	}
@@ -2008,8 +2219,8 @@ void optimize_vcd_file(void) {
     }
     else {
       if(pid) {
-        int stat;
-        int rc = waitpid(pid, &stat, 0);
+        int mystat;
+        int rc = waitpid(pid, &mystat, 0);
 	if(rc > 0) {
 	  free_2(GLOBALS->loaded_file_name);
 	  GLOBALS->loaded_file_name = buf;
@@ -2031,8 +2242,8 @@ void optimize_vcd_file(void) {
     }
     else {
       if(pid) {
-	int stat;
-	int rc = waitpid(pid, &stat, 0);
+	int mystat;
+	int rc = waitpid(pid, &mystat, 0);
         if(rc > 0) {
           free_2(GLOBALS->loaded_file_name);
 	  GLOBALS->loaded_file_name = buf;
@@ -2048,8 +2259,81 @@ void optimize_vcd_file(void) {
 #endif
 
 /*
- * $Id: main.c,v 1.31 2008/07/20 01:29:36 gtkwave Exp $
+ * $Id: main.c,v 1.55 2009/02/16 17:16:05 gtkwave Exp $
  * $Log: main.c,v $
+ * Revision 1.55  2009/02/16 17:16:05  gtkwave
+ * extload error hardening and recovery
+ *
+ * Revision 1.54  2009/01/28 20:06:20  gtkwave
+ * changed -ignore to a second --
+ *
+ * Revision 1.53  2009/01/28 16:28:58  gtkwave
+ * added -- -ignore passthrough processing for argv list in main.c
+ *
+ * Revision 1.52  2009/01/27 07:04:31  gtkwave
+ * added extload external process loader capability
+ *
+ * Revision 1.51  2009/01/19 07:13:11  gtkwave
+ * examine CYGWIN env var for "server" before printing warning for rtlbrowse
+ *
+ * Revision 1.50  2009/01/13 23:09:12  gtkwave
+ * added copy traces button to toolbar in gtkwave
+ *
+ * Revision 1.49  2009/01/12 16:01:45  gtkwave
+ * fixed OUTPUT_GETOPT for mingw
+ *
+ * Revision 1.48  2009/01/12 04:17:39  gtkwave
+ * added dynamic zoom for end for partial vcd
+ *
+ * Revision 1.47  2009/01/08 16:58:22  gtkwave
+ * added --output command line flag
+ *
+ * Revision 1.46  2009/01/02 06:24:28  gtkwave
+ * bumped copyright to 2009
+ *
+ * Revision 1.45  2009/01/02 06:12:48  gtkwave
+ * needed check for TCL presence for GLOBALS->interp cloning
+ *
+ * Revision 1.44  2009/01/02 06:11:00  gtkwave
+ * needed to clone GLOBALS->interp from one instance to the next in maketabs
+ *
+ * Revision 1.43  2009/01/02 06:01:51  gtkwave
+ * added getArgv for tcl commands
+ *
+ * Revision 1.42  2008/12/28 03:03:33  gtkwave
+ * Added scale_to_time_dimension rc variable and menu options.
+ *
+ * Revision 1.41  2008/12/25 04:07:29  gtkwave
+ * -Wshadow warning fixes
+ *
+ * Revision 1.40  2008/12/20 07:44:22  gtkwave
+ * experimental support for Tcl repscripts
+ *
+ * Revision 1.39  2008/11/17 23:08:54  gtkwave
+ * make images in toolbars smaller by removing border space
+ *
+ * Revision 1.38  2008/10/21 04:03:01  gtkwave
+ * setlocale disable for mingw on gtk init
+ *
+ * Revision 1.37  2008/10/13 22:16:52  gtkwave
+ * tcl interpreter integration
+ *
+ * Revision 1.36  2008/10/04 15:15:20  gtkwave
+ * gtk1 compatibility fixes
+ *
+ * Revision 1.35  2008/10/02 00:52:25  gtkwave
+ * added dnd of external filetypes into viewer
+ *
+ * Revision 1.34  2008/10/01 01:31:38  gtkwave
+ * more dnd fixes
+ *
+ * Revision 1.33  2008/09/26 17:05:10  gtkwave
+ * force open tree nodes in ctree on initial .sav file read (didn't happen
+ * before as ctree was not built yet)
+ *
+ * Revision 1.32  2008/09/16 00:01:25  gtkwave
+ * prelim drag and drop from external apps (now disabled)
+ *
  * Revision 1.31  2008/07/20 01:29:36  gtkwave
  * added command line option --comphier
  *
