@@ -66,16 +66,20 @@ enum FileType {
   GHW_FILE,
   VCD_FILE,
   VCD_RECODER_FILE,
+#ifdef EXTLOAD_SUFFIX
+  EXTLOAD_FILE,
+#endif
   NO_FILE
 };
 
-
-
 #endif
 
 /*
- * $Id: main.h,v 1.4 2008/07/01 18:51:07 gtkwave Exp $
+ * $Id: main.h,v 1.5 2009/01/27 07:04:31 gtkwave Exp $
  * $Log: main.h,v $
+ * Revision 1.5  2009/01/27 07:04:31  gtkwave
+ * added extload external process loader capability
+ *
  * Revision 1.4  2008/07/01 18:51:07  gtkwave
  * compiler warning fixes for amd64
  *
