@@ -33,6 +33,7 @@ void get_main_menu (GtkWidget *, GtkWidget **menubar);
 int file_quit_cmd_callback (GtkWidget *widget, gpointer data);
 int set_wave_menu_accelerator(char *str);
 int execute_script(char *name);
+char *append_array_row(nptr n);
 
 struct stringchain_t
 {
@@ -49,6 +50,7 @@ WV_MENU_FONVT,
 WV_MENU_FRW,
 WV_MENU_WRVCD,
 WV_MENU_WRLXT,
+WV_MENU_WRTIM,
 WV_MENU_WCLOSE,
 WV_MENU_SEP2VCD,
 WV_MENU_FPTF,
@@ -63,6 +65,10 @@ WV_MENU_SEP2LF,
 WV_MENU_FRSTMF,
 WV_MENU_SEP2STMF,
 #endif
+#if defined(HAVE_LIBTCL)
+WV_MENU_TCLSCR,
+WV_MENU_TCLSEP,
+#endif
 WV_MENU_FQY,
 WV_MENU_FQN,
 WV_MENU_ESTMH,
@@ -73,6 +79,7 @@ WV_MENU_EIA,
 WV_MENU_EAHT,
 WV_MENU_ERHA,
 WV_MENU_EC,
+WV_MENU_ECY,
 WV_MENU_EP,
 WV_MENU_SEP4,
 WV_MENU_EE,
@@ -104,8 +111,10 @@ WV_MENU_RFILL1,
 WV_MENU_RFILLOFF,
 WV_MENU_XLF_0,
 WV_MENU_XLF_1,
+#if !defined __MINGW32__ && !defined _MSC_VER
 WV_MENU_XLP_0,
 WV_MENU_XLP_1,
+#endif
 WV_MENU_ESCAH,
 WV_MENU_ESCFH,
 WV_MENU_SEP6,
@@ -187,6 +196,8 @@ WV_MENU_VLJS,
 WV_MENU_VRJS,
 WV_MENU_SEP16,
 WV_MENU_VZPS,
+WV_MENU_VZDYN,
+WV_MENU_VZDYNE,
 WV_MENU_VFTP,
 WV_MENU_SEP17,
 WV_MENU_RMRKS,
@@ -195,13 +206,19 @@ WV_MENU_USECOLOR,
 WV_MENU_USEBW,
 WV_MENU_SEP18,
 WV_MENU_LXTCC2Z,
+WV_MENU_SEP19,
+WV_MENU_TDSCALEX,
+WV_MENU_TDSCALES,
+WV_MENU_TDSCALEM,
+WV_MENU_TDSCALEU,
+WV_MENU_TDSCALEN,
+WV_MENU_TDSCALEP,
+WV_MENU_TDSCALEF,
 WV_MENU_HWH,
 WV_MENU_HWV,
-
 WV_MENU_NUMITEMS
 };
 
-
 void menu_new_viewer(GtkWidget *widget, gpointer data);
 void menu_write_vcd_file(GtkWidget *widget, gpointer data);
 void menu_write_lxt_file(GtkWidget *widget, gpointer data);
@@ -219,6 +236,7 @@ void menu_insert_analog_height_extension(GtkWidget *widget, gpointer data);
 void menu_alias(GtkWidget *widget, gpointer data);
 void menu_remove_aliases(GtkWidget *widget, gpointer data);
 void menu_cut_traces(GtkWidget *widget, gpointer data);
+void menu_copy_traces(GtkWidget *widget, gpointer data);
 void menu_paste_traces(GtkWidget *widget, gpointer data);
 void menu_expand(GtkWidget *widget, gpointer data);
 void menu_combine_down(GtkWidget *widget, gpointer data);
@@ -297,6 +315,13 @@ void menu_lxt_clk_compress(GtkWidget *widget, gpointer data);
 void menu_help(GtkWidget *widget, gpointer data);
 void menu_version(GtkWidget *widget, gpointer data);
 
+GtkItemFactoryEntry *retrieve_menu_items_array(int *num_items);
+
+void menu_read_stems_cleanup(GtkWidget *widget, gpointer data);
+void menu_new_viewer_tab_cleanup(GtkWidget *widget, gpointer data);
+
+void set_scale_to_time_dimension_toggles(void);
+
 /* These should eventually have error values */
 void write_save_helper(FILE *file);
 void read_save_helper(char *wname);
@@ -304,8 +329,45 @@ void read_save_helper(char *wname);
 #endif
 
 /*
- * $Id: menu.h,v 1.12 2008/03/25 03:22:11 gtkwave Exp $
+ * $Id: menu.h,v 1.24 2009/01/13 23:09:12 gtkwave Exp $
  * $Log: menu.h,v $
+ * Revision 1.24  2009/01/13 23:09:12  gtkwave
+ * added copy traces button to toolbar in gtkwave
+ *
+ * Revision 1.23  2009/01/12 04:17:39  gtkwave
+ * added dynamic zoom for end for partial vcd
+ *
+ * Revision 1.22  2008/12/28 03:03:34  gtkwave
+ * Added scale_to_time_dimension rc variable and menu options.
+ *
+ * Revision 1.21  2008/12/16 19:28:20  gtkwave
+ * more warnings cleanups
+ *
+ * Revision 1.20  2008/12/05 19:44:08  gtkwave
+ * prelim support for timinganalyzer file format export
+ *
+ * Revision 1.19  2008/12/04 19:21:00  gtkwave
+ * added zoom_dynamic option for partial VCD loading
+ *
+ * Revision 1.18  2008/11/27 19:37:38  gtkwave
+ * disable filter process in windows compiles
+ *
+ * Revision 1.17  2008/11/25 18:07:32  gtkwave
+ * added cut copy paste functionality that survives reload and can do
+ * multiple pastes on the same cut buffer
+ *
+ * Revision 1.16  2008/11/24 02:55:10  gtkwave
+ * use TCL_INCLUDE_SPEC to fix ubuntu compiles
+ *
+ * Revision 1.15  2008/11/19 19:08:34  gtkwave
+ * add tcl menu option, update file requester name reentrancy code
+ *
+ * Revision 1.14  2008/10/14 00:53:46  gtkwave
+ * enabled tcl scripts to call existing gtkwave style scripted menu functions
+ *
+ * Revision 1.13  2008/09/24 23:41:23  gtkwave
+ * drag from signal window into external process
+ *
  * Revision 1.12  2008/03/25 03:22:11  gtkwave
  * expanded zero fill to include also a one fill (for pre-inverted nets)
  *
