@@ -181,7 +181,7 @@ return(FALSE);
 }
 
 
-void create_mouseover(gint x, gint y, gint width, gint height)
+static void create_mouseover(gint x, gint y, gint width, gint height)
 {
 GLOBALS->mo_width_mouseover_c_1 = width;
 GLOBALS->mo_height_mouseover_c_1 = height;
@@ -385,8 +385,11 @@ if(flagged_name) { free_2(flagged_name); }
 }
 
 /*
- * $Id: mouseover.c,v 1.9 2008/07/01 18:51:07 gtkwave Exp $
+ * $Id: mouseover.c,v 1.10 2008/12/09 00:36:42 gtkwave Exp $
  * $Log: mouseover.c,v $
+ * Revision 1.10  2008/12/09 00:36:42  gtkwave
+ * added mouseover support for signal window
+ *
  * Revision 1.9  2008/07/01 18:51:07  gtkwave
  * compiler warning fixes for amd64
  *
