@@ -383,6 +383,23 @@ if(GLOBALS->ps_maxveclen>66)
 return(0);
 }
 
+int f_scale_to_time_dimension(char *str)
+{
+int which = tolower((int)(*str));
+DEBUG(printf("f_scale_to_time_dimension(\"%s\")\n",str));
+
+if(strchr(WAVE_SI_UNITS, which) || (which == 's'))
+	{
+	GLOBALS->scale_to_time_dimension = which;
+	}
+	else
+	{
+	GLOBALS->scale_to_time_dimension = 0;	/* also covers '*' case as not found above */
+	}
+
+return(0);
+}
+
 int f_show_base_symbols(char *str)
 {
 DEBUG(printf("f_show_base_symbols(\"%s\")\n",str));
@@ -460,6 +477,13 @@ GLOBALS->use_scrollbar_only=atoi_64(str)?1:0;
 return(0);
 }
 
+int f_use_scrollwheel_as_y(char *str)
+{
+DEBUG(printf("f_use_scrollwheel_as_y(\"%s\")\n",str));
+GLOBALS->use_scrollwheel_as_y=atoi_64(str)?1:0;
+return(0);
+}
+
 int f_use_standard_clicking(char *str)
 {
 DEBUG(printf("f_use_standard_clicking(\"%s\")\n",str));
@@ -553,6 +577,20 @@ GLOBALS->do_zoom_center=atoi_64(str)?1:0;
 return(0);
 }
 
+int f_zoom_dynamic(char *str)
+{
+DEBUG(printf("f_zoom_dynamic(\"%s\")\n",str));
+GLOBALS->zoom_dyn=atoi_64(str)?1:0;
+return(0);
+}
+
+int f_zoom_dynamic_end(char *str)
+{
+DEBUG(printf("f_zoom_dynamic_end(\"%s\")\n",str));
+GLOBALS->zoom_dyne=atoi_64(str)?1:0;
+return(0);
+}
+
 int f_zoom_pow10_snap(char *str)
 {
 DEBUG(printf("f_zoom_pow10_snap(\"%s\")\n",str));
@@ -688,6 +726,7 @@ static struct rc_entry rcitems[]=
 { "lxt_clock_compress_to_z", f_lxt_clock_compress_to_z },
 { "page_divisor", f_page_divisor },
 { "ps_maxveclen", f_ps_maxveclen },
+{ "scale_to_time_dimension", f_scale_to_time_dimension },
 { "show_base_symbols", f_show_base_symbols },
 { "show_grid", f_show_grid },
 { "splash_disable", f_splash_disable },
@@ -701,6 +740,7 @@ static struct rc_entry rcitems[]=
 { "use_pango_fonts", f_use_pango_fonts },
 { "use_roundcaps", f_use_roundcaps },
 { "use_scrollbar_only", f_use_scrollbar_only },
+{ "use_scrollwheel_as_y", f_use_scrollwheel_as_y },
 { "use_standard_clicking", f_use_standard_clicking },
 { "use_toolbutton_interface", f_use_toolbutton_interface },
 { "vcd_explicit_zero_subscripts", f_vcd_explicit_zero_subscripts },
@@ -713,6 +753,8 @@ static struct rc_entry rcitems[]=
 { "wave_scrolling", f_wave_scrolling },
 { "zoom_base", f_zoom_base },
 { "zoom_center", f_zoom_center },
+{ "zoom_dynamic", f_zoom_dynamic },
+{ "zoom_dynamic_end", f_zoom_dynamic_end },
 { "zoom_pow10_snap", f_zoom_pow10_snap }
 };
 
@@ -822,7 +864,7 @@ while(!feof(handle))
 	GLOBALS->rc_line_no++;
 	if((str=fgetmalloc(handle)))
 		{
-		int i, len;
+		int len;
 		len=strlen(str);
 		if(len)
 			{
@@ -881,8 +923,23 @@ return;
 }
 
 /*
- * $Id: rc.c,v 1.11 2008/02/21 04:14:21 gtkwave Exp $
+ * $Id: rc.c,v 1.16 2009/01/12 04:17:39 gtkwave Exp $
  * $Log: rc.c,v $
+ * Revision 1.16  2009/01/12 04:17:39  gtkwave
+ * added dynamic zoom for end for partial vcd
+ *
+ * Revision 1.15  2008/12/28 03:03:34  gtkwave
+ * Added scale_to_time_dimension rc variable and menu options.
+ *
+ * Revision 1.14  2008/12/25 03:21:57  gtkwave
+ * -Wshadow warning fixes
+ *
+ * Revision 1.13  2008/12/04 19:21:00  gtkwave
+ * added zoom_dynamic option for partial VCD loading
+ *
+ * Revision 1.12  2008/11/25 20:00:54  gtkwave
+ * added use_scrollwheel_as_y rc variable
+ *
  * Revision 1.11  2008/02/21 04:14:21  gtkwave
  * default color for X is red now
  *
