@@ -45,7 +45,6 @@ DEBUG(printf("picked: %s\n", render_targets[i]));
 static void pagesize_clicked(GtkWidget *widget, gpointer which)
 {
 int i;
-char *which_char;
 
 for(i=0;i<5;i++) GLOBALS->page_mutex_renderopt_c_1[i]=0;
 
@@ -58,7 +57,6 @@ DEBUG(printf("picked: %s\n", page_size[GLOBALS->page_size_type_renderopt_c_1]));
 static void rendertype_clicked(GtkWidget *widget, gpointer which)
 {
 int i;
-char *which_char;
 
 for(i=0;i<2;i++) GLOBALS->render_mutex_renderopt_c_1[i]=0;
 
@@ -315,8 +313,11 @@ void renderbox(char *title)
 }
 
 /*
- * $Id: renderopt.c,v 1.5 2007/09/12 17:26:45 gtkwave Exp $
+ * $Id: renderopt.c,v 1.6 2008/06/11 08:01:53 gtkwave Exp $
  * $Log: renderopt.c,v $
+ * Revision 1.6  2008/06/11 08:01:53  gtkwave
+ * gcc 4.3.x compiler warning fixes
+ *
  * Revision 1.5  2007/09/12 17:26:45  gtkwave
  * experimental ctx_swap_watchdog added...still tracking down mouse thrash crashes
  *
