@@ -198,6 +198,7 @@ if(must_update_screen)
         wavearea_configure_event(GLOBALS->wavearea, NULL);
 	}
 
+GLOBALS->dnd_cursor_timer = 0;
 GLOBALS->dnd_state = 0;
 }
 
@@ -207,7 +208,7 @@ GLOBALS->dnd_state = 0;
  */
 static gboolean DNDDragMotionCB(
         GtkWidget *widget, GdkDragContext *dc,
-        gint x, gint y, guint t,
+        gint xx, gint yy, guint tt,
         gpointer data
 )
 {
@@ -244,19 +245,19 @@ static gboolean DNDDragMotionCB(
 
         /* Only move? */
         if(dc->actions == GDK_ACTION_MOVE)
-            gdk_drag_status(dc, GDK_ACTION_MOVE, t);
+            gdk_drag_status(dc, GDK_ACTION_MOVE, tt);
         /* Only copy? */
         else if(dc->actions == GDK_ACTION_COPY)
-            gdk_drag_status(dc, GDK_ACTION_COPY, t);
+            gdk_drag_status(dc, GDK_ACTION_COPY, tt);
         /* Only link? */
         else if(dc->actions == GDK_ACTION_LINK)
-            gdk_drag_status(dc, GDK_ACTION_LINK, t);
+            gdk_drag_status(dc, GDK_ACTION_LINK, tt);
         /* Other action, check if listed in our actions list? */
         else if(dc->actions & suggested_action)
-            gdk_drag_status(dc, suggested_action, t);
+            gdk_drag_status(dc, suggested_action, tt);
         /* All else respond with 0. */
         else
-            gdk_drag_status(dc, 0, t);
+            gdk_drag_status(dc, 0, tt);
 #endif
 
 if(GLOBALS->std_dnd_tgt_on_signalarea || GLOBALS->std_dnd_tgt_on_wavearea)
@@ -338,6 +339,7 @@ if(GLOBALS->std_dnd_tgt_on_signalarea || GLOBALS->std_dnd_tgt_on_wavearea)
 
 		RenderSigs(rsig_trtarget, 0);
 
+		GLOBALS->dnd_cursor_timer = 1;
 		if((t)&&(which >= -1))
 			{
 			if(which >= GLOBALS->traces.total) { which = GLOBALS->traces.total-1; } 
@@ -585,6 +587,108 @@ scroll_event( GtkWidget * widget, GdkEventScroll * event )
 #endif
 
 
+static gboolean mouseover_timer(gpointer dummy)
+{
+static gboolean run_once = FALSE;
+gdouble x,y;
+GdkModifierType state;
+                 
+#ifdef WAVE_USE_GTK2
+gint xi, yi;
+#else
+GdkEventMotion event[1];
+event[0].deviceid = GDK_CORE_POINTER;  
+#endif
+
+if(run_once == FALSE) /* avoid any race conditions with the toolkit for uninitialized data */
+	{
+	run_once = TRUE;
+	return(TRUE);
+	}
+
+if(GLOBALS->dnd_cursor_timer)
+	{
+	GLOBALS->dnd_cursor_timer++;
+	if(GLOBALS->dnd_cursor_timer == 50)
+		{
+		GLOBALS->dnd_cursor_timer = 0;
+	        signalarea_configure_event(GLOBALS->signalarea, NULL);
+		}
+	}
+
+if(GLOBALS->mouseover_counter < 0) return(TRUE); /* mouseover is up in wave window so don't bother */
+                 
+WAVE_GDK_GET_POINTER(GLOBALS->signalarea->window, &x, &y, &xi, &yi, &state);
+WAVE_GDK_GET_POINTER_COPY;
+
+GLOBALS->mouseover_counter++;
+
+if(!((x>=0)&&(x<GLOBALS->signalarea->allocation.width)&&(y>=0)&&(y<GLOBALS->signalarea->allocation.height)))
+	{
+	move_mouseover_sigs(NULL, 0, 0, LLDescriptor(0));
+	}
+else
+if(GLOBALS->mouseover_counter == 10)
+	{
+	int num_traces_displayable=GLOBALS->wavearea->allocation.height/(GLOBALS->fontheight);
+	int yr = GLOBALS->cached_mouseover_y;
+	int i;
+	Trptr t=NULL;
+
+	num_traces_displayable--;   /* for the time trace that is always there */
+
+	yr-=GLOBALS->fontheight;
+	if(yr<0) goto bot;
+	yr/=GLOBALS->fontheight;             /* y now indicates the trace in question */
+	if(yr>num_traces_displayable) goto bot;
+
+	t=GLOBALS->topmost_trace;
+
+	for(i=0;i<yr;i++)
+	        {
+	        if(!t) goto bot;
+	        t=GiveNextTrace(t);
+	        }
+         
+	if(!t) goto bot;
+	if((t->flags&(TR_BLANK|TR_EXCLUDE)))
+	        {
+	        t = NULL;
+	        goto bot; 
+	        }
+	         
+	if(t->flags & TR_ANALOG_BLANK_STRETCH)  /* seek to real analog trace is present... */
+	        {
+	        while((t) && (t = t->t_prev))
+	                {
+	                if(!(t->flags & TR_ANALOG_BLANK_STRETCH))
+	                        {
+	                        if(t->flags & TR_ANALOGMASK)
+	                                {
+	                                break; /* found it */
+	                                }
+	                                else
+	                                {   
+	                                t = NULL;
+	                                }
+	                        }
+	                }
+	        }
+
+bot:
+	if(t)
+		{
+		move_mouseover_sigs(t, GLOBALS->cached_mouseover_x, GLOBALS->cached_mouseover_y, GLOBALS->tims.marker);
+		}
+		else
+		{
+		move_mouseover_sigs(NULL, 0, 0, LLDescriptor(0));
+		}
+	}
+
+return(TRUE);
+}
+
 static gint motion_notify_event_std(GtkWidget *widget, GdkEventMotion *event)
 {
 gdouble x,y;
@@ -606,6 +710,12 @@ if(event->is_hint)
 	state = event->state;
 	}
 
+GLOBALS->cached_mouseover_x = x;
+GLOBALS->cached_mouseover_y = y;
+GLOBALS->mouseover_counter = 0;
+
+move_mouseover_sigs(NULL, 0, 0, LLDescriptor(0));
+
 return(TRUE);
 }
 
@@ -1248,6 +1358,73 @@ wadj->step_increment=(gfloat)1.0;
 wadj->lower=(gfloat)0.0;
 wadj->upper=(gfloat)(GLOBALS->traces.visible ? GLOBALS->traces.visible : 1);
 
+if(GLOBALS->traces.scroll_bottom)
+	{
+	Trptr t = GLOBALS->traces.first;
+	int which = 0;
+	int scroll_top = -1, scroll_bottom = -1;
+	int cur_top = wadj->value;
+	int cur_bottom = cur_top + num_traces_displayable - 1;
+
+	while(t)
+		{
+		if(t == GLOBALS->traces.scroll_top)
+			{
+			scroll_top = which;
+			}
+
+		if(t == GLOBALS->traces.scroll_bottom)
+			{
+			scroll_bottom = which;
+			break;
+			}
+
+		t = GiveNextTrace(t);
+		which++;
+		}
+
+	GLOBALS->traces.scroll_top = GLOBALS->traces.scroll_bottom = NULL;
+
+	if((scroll_top >= 0) && (scroll_bottom >= 0))
+		{
+		if((scroll_top > cur_top) && (scroll_bottom <= cur_bottom))
+			{
+			/* nothing */
+			}	
+			else
+			{
+			if((scroll_bottom - scroll_top + 1) >= num_traces_displayable)			
+				{
+				wadj->value=(gfloat)(scroll_bottom - num_traces_displayable + 1);
+				}
+				else
+				{
+				int midpoint = (cur_top + cur_bottom) / 2;
+
+				if(scroll_top <= cur_top)
+					{
+					wadj->value=(gfloat)scroll_top-1;
+					}
+				else if(scroll_top >= cur_bottom)
+					{
+					wadj->value=(gfloat)(scroll_bottom - num_traces_displayable + 1);
+					}
+				else
+				if(scroll_top < midpoint)
+					{
+					wadj->value=(gfloat)scroll_top-1;
+					}
+				else
+					{
+					wadj->value=(gfloat)(scroll_bottom - num_traces_displayable + 1);
+					}
+				}
+
+			if(wadj->value < 0.0) wadj->value = 0.0;
+			}
+		}
+	}
+
 if(num_traces_displayable>GLOBALS->traces.visible)
 	{
 	wadj->value=(gfloat)(GLOBALS->trtarget_signalwindow_c_1=0);
@@ -1416,6 +1593,7 @@ if(GLOBALS->use_standard_clicking)
 	gtkwave_signal_connect(GTK_OBJECT(GLOBALS->signalarea), "button_press_event",GTK_SIGNAL_FUNC(button_press_event_std), NULL);
 	gtkwave_signal_connect(GTK_OBJECT(GLOBALS->signalarea), "button_release_event", GTK_SIGNAL_FUNC(button_release_event_std), NULL);
 	gtkwave_signal_connect(GTK_OBJECT(GLOBALS->signalarea), "motion_notify_event",GTK_SIGNAL_FUNC(motion_notify_event_std), NULL);
+	g_timeout_add(100, mouseover_timer, NULL);
 
 #ifdef WAVE_USE_GTK2
 	gtkwave_signal_connect(GTK_OBJECT(GLOBALS->signalarea), "scroll_event",GTK_SIGNAL_FUNC(scroll_event), NULL);
@@ -1494,8 +1672,30 @@ gtk_signal_disconnect(GTK_OBJECT(GLOBALS->mainwindow), id);
 
 
 /*
- * $Id: signalwindow.c,v 1.33 2008/08/18 16:10:54 gtkwave Exp $
+ * $Id: signalwindow.c,v 1.40 2008/12/25 03:21:57 gtkwave Exp $
  * $Log: signalwindow.c,v $
+ * Revision 1.40  2008/12/25 03:21:57  gtkwave
+ * -Wshadow warning fixes
+ *
+ * Revision 1.39  2008/12/20 19:42:11  gtkwave
+ * add static initializer to timer functions to avoid non-initialized viewer
+ * state when first starting (if timer interrupt fires)
+ *
+ * Revision 1.38  2008/12/20 05:45:03  gtkwave
+ * gtk1 compatibility and -Wshadow warning fixes
+ *
+ * Revision 1.37  2008/12/18 01:31:30  gtkwave
+ * integrated experimental autoscroll code on signal adds
+ *
+ * Revision 1.36  2008/12/17 16:22:31  gtkwave
+ * removed clearing of dnd timer in tree drag code
+ *
+ * Revision 1.35  2008/12/16 18:09:49  gtkwave
+ * add countdown timer to remove dnd cursor in signalwindow
+ *
+ * Revision 1.34  2008/12/09 00:36:42  gtkwave
+ * added mouseover support for signal window
+ *
  * Revision 1.33  2008/08/18 16:10:54  gtkwave
  * adding sticky click semantics on already selected entries
  *
