@@ -57,6 +57,7 @@ void simplereqbox(char *title, int width, char *default_text,
     install_focus_cb(GLOBALS->window_simplereq_c_9, ((char *)&GLOBALS->window_simplereq_c_9) - ((char *)GLOBALS));
 
     gtk_grab_add(GLOBALS->window_simplereq_c_9);
+    gtk_window_set_transient_for(GTK_WINDOW(GLOBALS->window_simplereq_c_9), GTK_WINDOW(GLOBALS->mainwindow));
     gtk_widget_set_usize( GTK_WIDGET (GLOBALS->window_simplereq_c_9), width, 55 + 52);
     gtk_window_set_title(GTK_WINDOW (GLOBALS->window_simplereq_c_9), title);
     gtkwave_signal_connect(GTK_OBJECT (GLOBALS->window_simplereq_c_9), "delete_event",(GtkSignalFunc) destroy_callback, NULL);
@@ -111,8 +112,11 @@ void simplereqbox(char *title, int width, char *default_text,
 }
 
 /*
- * $Id: simplereq.c,v 1.4 2007/09/12 17:26:45 gtkwave Exp $
+ * $Id: simplereq.c,v 1.5 2008/11/14 19:01:28 gtkwave Exp $
  * $Log: simplereq.c,v $
+ * Revision 1.5  2008/11/14 19:01:28  gtkwave
+ * updated simplereq so the window is transient
+ *
  * Revision 1.4  2007/09/12 17:26:45  gtkwave
  * experimental ctx_swap_watchdog added...still tracking down mouse thrash crashes
  *
