@@ -68,6 +68,13 @@ struct symbol *symbol;
 };
 
 
+struct string_chain_t
+{
+struct string_chain_t *next;
+char *str;
+};
+
+
 struct symbol *symfind(char *, unsigned int *);
 struct symbol *symadd(char *, int);
 struct symbol *symadd_name_exists(char *name, int hv);
@@ -110,8 +117,12 @@ void splash_sync(off_t current, off_t total);
 #endif
 
 /*
- * $Id: symbol.h,v 1.2 2007/08/26 21:35:45 gtkwave Exp $
+ * $Id: symbol.h,v 1.3 2008/09/26 17:05:10 gtkwave Exp $
  * $Log: symbol.h,v $
+ * Revision 1.3  2008/09/26 17:05:10  gtkwave
+ * force open tree nodes in ctree on initial .sav file read (didn't happen
+ * before as ctree was not built yet)
+ *
  * Revision 1.2  2007/08/26 21:35:45  gtkwave
  * integrated global context management from SystemOfCode2007 branch
  *
