@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2006.
+ * Copyright (c) Tony Bybell 1999-2008.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -297,7 +297,7 @@ if(t->next)
 		it=it->next;
 		} while(it);
 	
-	srt = wave_alloca(cnt * sizeof(struct tree *));
+	srt = malloc_2(cnt * sizeof(struct tree *)); /* was previously wave_alloca but with too many signals the stack overflows */
 	for(i=0;i<cnt;i++)
 		{
 		srt[i] = t;
@@ -328,6 +328,8 @@ if(t->next)
 		{
 		treesort(srt[i]->child, srt[i]);
 		}
+
+	free_2(srt);
 	}
 else if (t->child)
 	{
@@ -597,8 +599,11 @@ if(!GLOBALS->hier_grouping)
 #endif
 
 /*
- * $Id: tree.c,v 1.2 2007/08/26 21:35:46 gtkwave Exp $
+ * $Id: tree.c,v 1.3 2008/12/26 20:47:59 gtkwave Exp $
  * $Log: tree.c,v $
+ * Revision 1.3  2008/12/26 20:47:59  gtkwave
+ * fix for stack overflow crash on dumpfiles with very many signals
+ *
  * Revision 1.2  2007/08/26 21:35:46  gtkwave
  * integrated global context management from SystemOfCode2007 branch
  *
