@@ -17,7 +17,7 @@
 #include "lx2.h"
 #include "debug.h"
 
-void dnd_setup(GtkWidget *src, GtkWidget *w)
+void dnd_setup(GtkWidget *src, GtkWidget *w, int enable_receive)
 {
 	GtkWidget *win = w;
 	GtkTargetEntry target_entry[3];
@@ -65,6 +65,7 @@ void dnd_setup(GtkWidget *src, GtkWidget *w)
 		/* Set the drag source for this widget, allowing the user
 		 * to drag items off of this clist.
 		 */
+		if(src)
 		gtk_drag_source_set(
 			src,
 			GDK_BUTTON1_MASK | GDK_BUTTON2_MASK,
@@ -645,6 +646,7 @@ for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->which;i<=fetchhigh(GLOB
 
 set_window_idle(widget);
 
+GLOBALS->traces.scroll_top = GLOBALS->traces.scroll_bottom = GLOBALS->traces.last;
 MaxSignalLength();
 signalarea_configure_event(GLOBALS->signalarea, NULL);
 wavearea_configure_event(GLOBALS->wavearea, NULL);
@@ -811,8 +813,17 @@ void treebox(char *title, GtkSignalFunc func, GtkWidget *old_window)
 }
 
 /*
- * $Id: treesearch_gtk1.c,v 1.9 2008/05/08 20:10:04 gtkwave Exp $
+ * $Id: treesearch_gtk1.c,v 1.12 2008/12/18 01:31:30 gtkwave Exp $
  * $Log: treesearch_gtk1.c,v $
+ * Revision 1.12  2008/12/18 01:31:30  gtkwave
+ * integrated experimental autoscroll code on signal adds
+ *
+ * Revision 1.11  2008/10/04 15:15:20  gtkwave
+ * gtk1 compatibility fixes
+ *
+ * Revision 1.10  2008/09/16 00:01:27  gtkwave
+ * prelim drag and drop from external apps (now disabled)
+ *
  * Revision 1.9  2008/05/08 20:10:04  gtkwave
  * 2.4 not required for dnd so requirement relaxed
  *
