@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tristan Gingold and Tony Bybell 2006-2008.
+ * Copyright (c) Tristan Gingold and Tony Bybell 2006-2009.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -11,6 +11,7 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <string.h>
+#include <ctype.h>
 #include "gtk12compat.h"
 #include "analyzer.h"
 #include "tree.h"
@@ -19,6 +20,8 @@
 #include "lx2.h"
 #include "busy.h"
 #include "debug.h"
+#include "hierpack.h"
+#include "tcl_helper.h"
 
 
 enum { VIEW_DRAG_INACTIVE, TREE_TO_VIEW_DRAG_ACTIVE, SEARCH_TO_VIEW_DRAG_ACTIVE };
@@ -197,11 +200,11 @@ if(ctree)
 			if(zap == name_end)
 				{
 				GtkCTreeNode **nodehist = wave_alloca(depth * sizeof(GtkCTreeNode *));
-				int *exp = wave_alloca(depth * sizeof(int));
+				int *exp1 = wave_alloca(depth * sizeof(int));
 				int i = depth-1;
 
 				nodehist[i] = node;
-				exp[i--] = 1;
+				exp1[i--] = 1;
 				/* now work backwards up to parent getting the node open/close history*/
 				gctr = GTK_CTREE_ROW(node);
 				while(gctr->parent)
@@ -209,7 +212,7 @@ if(ctree)
 					node = gctr->parent;
 				        gctr = GTK_CTREE_ROW(node);
 					nodehist[i] = node;
-					exp[i--] = gctr->expanded;
+					exp1[i--] = gctr->expanded;
 				        }        
 
 				gtk_clist_freeze(GTK_CLIST(ctree));
@@ -223,7 +226,7 @@ if(ctree)
 				/* work backwards and close up nodes that were originally closed */
 				for(i=depth-1;i>=0;i--)
 					{
-					if(exp[i])
+					if(exp1[i])
 						{
 						gtk_ctree_expand(ctree, nodehist[i]);
 						}
@@ -244,6 +247,7 @@ if(ctree)
 				depth++;
 
 				node = gctr->children;
+				if(!node) break;
 				gctr = GTK_CTREE_ROW(node);
 				if(!gctr) break;
 
@@ -422,7 +426,6 @@ if(node)
          
 	for(i=depth-1;i>=0;i--)
 	        {
-	        struct tree *t;
 	        gctr[i] = GTK_CTREE_ROW(node);
 	        t = gctr[i]->row.data;
 	        len += (strlen(t->name) + 1);
@@ -434,7 +437,7 @@ if(node)
 
 	for(i=0;i<depth;i++)
 	        {
-	        struct tree *t = gctr[i]->row.data;
+	        t = gctr[i]->row.data;
 	        strcat(tstring, t->name);
 	        strcat(tstring, hier_suffix);
 	        }
@@ -962,6 +965,10 @@ action_callback(enum cb_action action)
 
   sig_selection_foreach_finalize((void *)action);
 
+  if(action == ACTION_APPEND)
+	{
+	GLOBALS->traces.scroll_top = GLOBALS->traces.scroll_bottom = GLOBALS->traces.last;
+	}
   MaxSignalLength();
   signalarea_configure_event(GLOBALS->signalarea, NULL);
   wavearea_configure_event(GLOBALS->wavearea, NULL);
@@ -996,6 +1003,7 @@ static void destroy_callback(GtkWidget *widget, GtkWidget *nothing)
   GLOBALS->window_treesearch_gtk2_c_12 = NULL;
   GLOBALS->dnd_sigview = NULL;
   GLOBALS->gtk2_tree_frame = NULL;
+  GLOBALS->ctree_main = NULL;
   free_afl();
 
   if(GLOBALS->selected_hierarchy_name)
@@ -1009,6 +1017,7 @@ static void destroy_callback(GtkWidget *widget, GtkWidget *nothing)
 
 /* view_selection_func is commented out for now... */
 
+#if 0
 static gboolean
   view_selection_func (GtkTreeSelection *selection,
                        GtkTreeModel     *model,
@@ -1016,7 +1025,6 @@ static gboolean
                        gboolean          path_currently_selected,
                        gpointer          userdata)
   {
-/*
     GtkTreeIter iter;
 
     if (gtk_tree_model_get_iter(model, &iter, path))
@@ -1036,9 +1044,9 @@ static gboolean
 
       g_free(name);
     }
-*/
     return TRUE; /* allow selection state to change */
   }
+#endif
 
 /**********************************************************************/
 
@@ -1170,7 +1178,7 @@ do_tooltips:
       }
 
     GLOBALS->dnd_sigview = sig_view;
-    dnd_setup(GLOBALS->dnd_sigview, GLOBALS->signalarea);
+    dnd_setup(GLOBALS->dnd_sigview, GLOBALS->signalarea, 0);
 
     sig_frame = gtk_frame_new (NULL);
     gtk_container_border_width (GTK_CONTAINER (sig_frame), 3);
@@ -1686,6 +1694,7 @@ signalarea_configure_event(GLOBALS->signalarea, NULL);
 wavearea_configure_event(GLOBALS->wavearea, NULL);
 }
 
+
 static void DNDEndCB(
 	GtkWidget *widget, GdkDragContext *dc, gpointer data
 )
@@ -1696,7 +1705,10 @@ if((widget == NULL) || (dc == NULL))
 	return;
 	}
 
-if(GLOBALS->tree_dnd_begin == VIEW_DRAG_INACTIVE) return; /* to keep cut and paste in signalwindow from conflicting */
+if(GLOBALS->tree_dnd_begin == VIEW_DRAG_INACTIVE) 
+	{
+	return; /* to keep cut and paste in signalwindow from conflicting */
+	}
 
 if(GLOBALS->tree_dnd_requested)
 	{
@@ -1794,13 +1806,67 @@ static void DNDDataRequestCB(
 	gpointer data
 )
 {
+int upd = 0;
 GLOBALS->tree_dnd_requested = 1;  /* indicate that a request for data occurred... */
+
+if(widget == GLOBALS->clist_search_c_3)	/* from search */
+	{
+	char *text = add_dnd_from_searchbox();
+	if(text)
+		{
+		gtk_selection_data_set(selection_data,GDK_SELECTION_TYPE_STRING, 8, (guchar*)text, strlen(text));
+		free_2(text);
+		}
+	upd = 1;
+	}
+else if(widget == GLOBALS->signalarea)
+	{
+	char *text = add_dnd_from_signal_window();
+	if(text)
+		{
+		char *text2 = emit_gtkwave_savefile_formatted_entries_in_tcl_list(GLOBALS->traces.first, TRUE);
+		if(text2)
+			{
+			int textlen = strlen(text);
+			int text2len = strlen(text2);
+			char *pnt = calloc_2(1, textlen + text2len + 1);
+			
+			memcpy(pnt, text, textlen);
+			memcpy(pnt + textlen, text2, text2len);
+
+			free_2(text2);
+			free_2(text);
+			text = pnt;
+			}
+
+		gtk_selection_data_set(selection_data,GDK_SELECTION_TYPE_STRING, 8, (guchar*)text, strlen(text));
+		free_2(text);
+		}
+	upd = 1;
+	}
+else if(widget == GLOBALS->dnd_sigview)
+	{
+	char *text = add_dnd_from_tree_window();
+	if(text)
+		{
+		gtk_selection_data_set(selection_data,GDK_SELECTION_TYPE_STRING, 8, (guchar*)text, strlen(text));
+		free_2(text);
+		}
+	upd = 1;
+	}
+
+if(upd)
+	{
+	MaxSignalLength();
+	signalarea_configure_event(GLOBALS->signalarea, NULL);
+	wavearea_configure_event(GLOBALS->wavearea, NULL);
+	}
 }
 
 /*
  *      DND "drag_data_received" handler. When DNDDataRequestCB()
  *	calls gtk_selection_data_set() to send out the data, this function
- *	recieves it and is responsible for handling it.
+ *	receives it and is responsible for handling it.
  *
  *	This is also the only DND callback function where the given
  *	inputs may reflect those of the drop target so we need to check
@@ -1809,11 +1875,74 @@ GLOBALS->tree_dnd_requested = 1;  /* indicate that a request for data occurred..
 static void DNDDataReceivedCB(
 	GtkWidget *widget, GdkDragContext *dc,
 	gint x, gint y, GtkSelectionData *selection_data,
-	guint info, guint t, gpointer data
-)
-{
+	guint info, guint t, gpointer data) {
+    gboolean same;
+    GtkWidget *source_widget;
+
+    if((widget == NULL) || (data == NULL) || (dc == NULL)) return;
+
+    /* Important, check if we actually got data.  Sometimes errors
+     * occure and selection_data will be NULL.
+     */
+    if(selection_data == NULL)     return;
+    if(selection_data->length < 0) return;
+
+    /* Source and target widgets are the same? */
+    source_widget = gtk_drag_get_source_widget(dc);
+    same = (source_widget == widget) ? TRUE : FALSE;
+
+    if(source_widget)
+    if((source_widget == GLOBALS->clist_search_c_3) || /* from search */
+       (source_widget == GLOBALS->signalarea) ||
+       (source_widget == GLOBALS->dnd_sigview))
+		{
+		/* use internal mechanism instead of passing names around... */
+		return;
+		}
+
+    GLOBALS->dnd_state = 0;
+    GLOBALS->tree_dnd_requested = 0;
+
+    /* Now check if the data format type is one that we support
+     * (remember, data format type, not data type).
+     *
+     * We check this by testing if info matches one of the info
+     * values that we have defined.
+     *
+     * Note that we can also iterate through the atoms in:
+     *	GList *glist = dc->targets;
+     *
+     *	while(glist != NULL)
+     *	{
+     *	    gchar *name = gdk_atom_name((GdkAtom)glist->data);
+     *	     * strcmp the name to see if it matches
+     *	     * one that we support
+     *	     *
+     *	    glist = glist->next;
+     *	}
+     */
+    if((info == WAVE_DRAG_TAR_INFO_0) ||
+       (info == WAVE_DRAG_TAR_INFO_1) ||
+       (info == WAVE_DRAG_TAR_INFO_2))
+    {
+    int num_found ;
+
+    /* printf("XXX %08x '%s'\n", selection_data->data, selection_data->data); */
+    if(!(num_found = process_url_list((char *)selection_data->data)))
+	{
+    	num_found = process_tcl_list((char *)selection_data->data, TRUE);
+	}
+	
+    if(num_found)
+	{
+	MaxSignalLength();
+	signalarea_configure_event(GLOBALS->signalarea, NULL);
+	wavearea_configure_event(GLOBALS->wavearea, NULL);
+	}
+    }
 }
 
+
 /*
  *	DND "drag_data_delete" handler, this function is called when
  *	the data on the source `should' be deleted (ie if the DND was
@@ -1830,7 +1959,7 @@ static void DNDDataDeleteCB(
 /***********************/
 
 
-void dnd_setup(GtkWidget *src, GtkWidget *w)
+void dnd_setup(GtkWidget *src, GtkWidget *w, int enable_receive)
 {
 	GtkWidget *win = w;
 	GtkTargetEntry target_entry[3];
@@ -1875,25 +2004,87 @@ void dnd_setup(GtkWidget *src, GtkWidget *w)
 		/* Set the drag source for this widget, allowing the user
 		 * to drag items off of this clist.
 		 */
-		gtk_drag_source_set(
-			src,
-			GDK_BUTTON1_MASK | GDK_BUTTON2_MASK,
-                        target_entry,
-                        sizeof(target_entry) / sizeof(GtkTargetEntry),
-			GDK_ACTION_MOVE | GDK_ACTION_COPY
-		);
-		/* Set DND signals on clist. */
-		gtkwave_signal_connect(GTK_OBJECT(src), "drag_begin", GTK_SIGNAL_FUNC(DNDBeginCB), win);
-                gtkwave_signal_connect(GTK_OBJECT(src), "drag_end", GTK_SIGNAL_FUNC(DNDEndCB), win);
-                gtkwave_signal_connect(GTK_OBJECT(src), "drag_data_get", GTK_SIGNAL_FUNC(DNDDataRequestCB), win);
-                gtkwave_signal_connect(GTK_OBJECT(src), "drag_data_received", GTK_SIGNAL_FUNC(DNDDataReceivedCB), win);
-                gtkwave_signal_connect(GTK_OBJECT(src), "drag_data_delete", GTK_SIGNAL_FUNC(DNDDataDeleteCB), win);
+		if(src)
+			{
+			gtk_drag_source_set(
+				src,
+				GDK_BUTTON1_MASK | GDK_BUTTON2_MASK,
+	                        target_entry,
+	                        sizeof(target_entry) / sizeof(GtkTargetEntry),
+				GDK_ACTION_MOVE | GDK_ACTION_COPY
+			);
+			/* Set DND signals on clist. */
+			gtkwave_signal_connect(GTK_OBJECT(src), "drag_begin", GTK_SIGNAL_FUNC(DNDBeginCB), win);
+	                gtkwave_signal_connect(GTK_OBJECT(src), "drag_end", GTK_SIGNAL_FUNC(DNDEndCB), win);
+	                gtkwave_signal_connect(GTK_OBJECT(src), "drag_data_get", GTK_SIGNAL_FUNC(DNDDataRequestCB), win);
+	                gtkwave_signal_connect(GTK_OBJECT(src), "drag_data_delete", GTK_SIGNAL_FUNC(DNDDataDeleteCB), win);
+			}
+
+                if(enable_receive) gtkwave_signal_connect(GTK_OBJECT(w),   "drag_data_received", GTK_SIGNAL_FUNC(DNDDataReceivedCB), win);
 	}
 }
 
 /*
- * $Id: treesearch_gtk2.c,v 1.16 2008/08/18 16:10:54 gtkwave Exp $
+ * $Id: treesearch_gtk2.c,v 1.35 2009/01/21 02:24:15 gtkwave Exp $
  * $Log: treesearch_gtk2.c,v $
+ * Revision 1.35  2009/01/21 02:24:15  gtkwave
+ * gtk1 compile fixes, ensure ctree_main is available for force_open_tree_node
+ *
+ * Revision 1.34  2008/12/25 04:07:29  gtkwave
+ * -Wshadow warning fixes
+ *
+ * Revision 1.33  2008/12/18 01:31:30  gtkwave
+ * integrated experimental autoscroll code on signal adds
+ *
+ * Revision 1.32  2008/12/17 16:22:31  gtkwave
+ * removed clearing of dnd timer in tree drag code
+ *
+ * Revision 1.31  2008/12/16 18:09:49  gtkwave
+ * add countdown timer to remove dnd cursor in signalwindow
+ *
+ * Revision 1.30  2008/12/04 17:22:33  gtkwave
+ * fix crash on invalid node for force tree open
+ *
+ * Revision 1.29  2008/11/25 18:07:32  gtkwave
+ * added cut copy paste functionality that survives reload and can do
+ * multiple pastes on the same cut buffer
+ *
+ * Revision 1.28  2008/10/02 00:52:25  gtkwave
+ * added dnd of external filetypes into viewer
+ *
+ * Revision 1.27  2008/10/01 01:31:38  gtkwave
+ * more dnd fixes
+ *
+ * Revision 1.26  2008/09/29 22:46:39  gtkwave
+ * complex dnd handling with gtkwave trace attributes
+ *
+ * Revision 1.25  2008/09/27 19:08:39  gtkwave
+ * compiler warning fixes
+ *
+ * Revision 1.24  2008/09/27 06:26:35  gtkwave
+ * twinwave (XEmbed) fixes for self-dnd in signal window
+ *
+ * Revision 1.23  2008/09/25 01:41:36  gtkwave
+ * drag from tree clist window into external process
+ *
+ * Revision 1.22  2008/09/24 23:41:25  gtkwave
+ * drag from signal window into external process
+ *
+ * Revision 1.21  2008/09/24 18:54:00  gtkwave
+ * drag from search widget into external processes
+ *
+ * Revision 1.20  2008/09/24 02:22:49  gtkwave
+ * added (commented out) prelim support for dragging names from viewer
+ *
+ * Revision 1.19  2008/09/23 18:23:03  gtkwave
+ * adding more support for DnD from external apps
+ *
+ * Revision 1.18  2008/09/22 03:27:03  gtkwave
+ * more DND adds
+ *
+ * Revision 1.17  2008/09/16 00:01:27  gtkwave
+ * prelim drag and drop from external apps (now disabled)
+ *
  * Revision 1.16  2008/08/18 16:10:54  gtkwave
  * adding sticky click semantics on already selected entries
  *
@@ -1998,4 +2189,3 @@ void dnd_setup(GtkWidget *src, GtkWidget *w)
  * initial release
  *
  */
-
