@@ -33,6 +33,7 @@
 #include "wavealloca.h"
 #include "debug.h"
 #include "tree.h"
+#include "jrb.h"
 
 #define VCD_SIZE_WARN (256)	/* number of MB size where converter warning message appears */
 #define VCD_BSIZ 32768	/* size of getch() emulation buffer--this val should be ok */
@@ -128,8 +129,11 @@ int vcd_keyword_code(const char *s, unsigned int len);
 #endif
 
 /*
- * $Id: vcd.h,v 1.2 2007/08/26 21:35:46 gtkwave Exp $
+ * $Id: vcd.h,v 1.3 2008/07/18 17:27:01 gtkwave Exp $
  * $Log: vcd.h,v $
+ * Revision 1.3  2008/07/18 17:27:01  gtkwave
+ * adding hierpack code
+ *
  * Revision 1.2  2007/08/26 21:35:46  gtkwave
  * integrated global context management from SystemOfCode2007 branch
  *
