@@ -1024,6 +1024,7 @@ for(;;)
 
 			vtok=get_token();
 			if((vtok==T_END)||(vtok==T_EOF)) break;
+			fractional_timescale_fix(GLOBALS->yytext_vcd_partial_c_2);
 			GLOBALS->time_scale=atoi_64(GLOBALS->yytext_vcd_partial_c_2);
 			if(!GLOBALS->time_scale) GLOBALS->time_scale=1;
 			for(i=0;i<GLOBALS->yylen_vcd_partial_c_2;i++)
@@ -1048,6 +1049,8 @@ for(;;)
 				case 'n':
 				case 'p':
 				case 'f':
+				case 'a':
+				case 'z':
 					GLOBALS->time_dimension=prefix;
 					break;
 				case 's':
@@ -1511,17 +1514,17 @@ for(;;)
 				/* catchall for events when header over */
 				if(GLOBALS->yytext_vcd_partial_c_2[0]=='#')
 					{
-					TimeType time;
-					time=atoi_64(GLOBALS->yytext_vcd_partial_c_2+1);
+					TimeType tim;
+					tim=atoi_64(GLOBALS->yytext_vcd_partial_c_2+1);
 					
 					if(GLOBALS->start_time_vcd_partial_c_2<0)
 						{
-						GLOBALS->start_time_vcd_partial_c_2=time;
+						GLOBALS->start_time_vcd_partial_c_2=tim;
 						}
 
-					GLOBALS->current_time_vcd_partial_c_2=time;
-					if(GLOBALS->end_time_vcd_partial_c_2<time) GLOBALS->end_time_vcd_partial_c_2=time;	/* in case of malformed vcd files */
-					DEBUG(fprintf(stderr,"#"TTFormat"\n",time));
+					GLOBALS->current_time_vcd_partial_c_2=tim;
+					if(GLOBALS->end_time_vcd_partial_c_2<tim) GLOBALS->end_time_vcd_partial_c_2=tim;	/* in case of malformed vcd files */
+					DEBUG(fprintf(stderr,"#"TTFormat"\n",tim));
 					}
 					else
 					{
@@ -1539,7 +1542,7 @@ for(;;)
 				{
 				struct blackout_region_t *bt = calloc_2(1, sizeof(struct blackout_region_t));
 
-				bt->bstart = GLOBALS->current_time_vcd_partial_c_2;
+				bt->bstart = GLOBALS->current_time_vcd_partial_c_2 * GLOBALS->time_scale;
 				bt->next = GLOBALS->blackout_regions;
 				GLOBALS->blackout_regions = bt;
 				}
@@ -1549,7 +1552,7 @@ for(;;)
 			GLOBALS->dumping_off_vcd_partial_c_2=0;
 			if((GLOBALS->blackout_regions)&&(GLOBALS->blackout_regions->bstart>GLOBALS->blackout_regions->bend))
 				{
-				GLOBALS->blackout_regions->bend = GLOBALS->current_time_vcd_partial_c_2;
+				GLOBALS->blackout_regions->bend = GLOBALS->current_time_vcd_partial_c_2 * GLOBALS->time_scale;
 				}
 			break;
 		case T_DUMPVARS:
@@ -1567,7 +1570,7 @@ for(;;)
 		case T_EOF:
 			if((GLOBALS->blackout_regions)&&(GLOBALS->blackout_regions->bstart>GLOBALS->blackout_regions->bend))
 				{
-				GLOBALS->blackout_regions->bend = GLOBALS->current_time_vcd_partial_c_2;
+				GLOBALS->blackout_regions->bend = GLOBALS->current_time_vcd_partial_c_2 * GLOBALS->time_scale;
 				}
 			return;
 		default:
@@ -1579,7 +1582,7 @@ for(;;)
 
 /*******************************************************************************/
 
-hptr add_histent_p(TimeType time, struct Node *n, char ch, int regadd, char *vector)
+hptr add_histent_p(TimeType tim, struct Node *n, char ch, int regadd, char *vector)
 {
 struct HistEnt *he, *rc;
 char heval;
@@ -1595,12 +1598,12 @@ if(!(rc=n->curr))
 	n->curr=he;
 	n->head.next=he;
 
-	add_histent_p(time,n,ch,regadd, vector);
+	add_histent_p(tim,n,ch,regadd, vector);
 	rc = he;
 	}
 	else
 	{
-	if(regadd) { time*=(GLOBALS->time_scale); }
+	if(regadd) { tim*=(GLOBALS->time_scale); }
 
 	if(ch=='0')              heval=AN_0; else
 	if(ch=='1')              heval=AN_1; else
@@ -1612,12 +1615,12 @@ if(!(rc=n->curr))
         if((ch=='l')||(ch=='L')) heval=AN_L; else
         /* if(ch=='-') */        heval=AN_DASH;		/* default */
 	
-	if((n->curr->v.h_val!=heval)||(time==GLOBALS->start_time_vcd_partial_c_2)||(GLOBALS->vcd_preserve_glitches)) /* same region == go skip */ 
+	if((n->curr->v.h_val!=heval)||(tim==GLOBALS->start_time_vcd_partial_c_2)||(GLOBALS->vcd_preserve_glitches)) /* same region == go skip */ 
         	{
-		if(n->curr->time==time)
+		if(n->curr->time==tim)
 			{
 			DEBUG(printf("Warning: Glitch at time ["TTFormat"] Signal [%p], Value [%c->%c].\n",
-				time, n, AN_STR[n->curr->v.h_val], ch));
+				tim, n, AN_STR[n->curr->v.h_val], ch));
 			n->curr->v.h_val=heval;		/* we have a glitch! */
 
 			GLOBALS->num_glitches_vcd_partial_c_3++;
@@ -1630,7 +1633,7 @@ if(!(rc=n->curr))
 			else
 			{
                 	he=histent_calloc();
-                	he->time=time;
+                	he->time=tim;
                 	he->v.h_val=heval;
 
                 	n->curr->next=he;
@@ -1656,17 +1659,17 @@ switch(ch)
 		n->curr=he;
 		n->head.next=he;
 	
-		add_histent_p(time,n,ch,regadd, vector);
+		add_histent_p(tim,n,ch,regadd, vector);
 		rc = he;
 		}
 		else
 		{
-		if(regadd) { time*=(GLOBALS->time_scale); }
+		if(regadd) { tim*=(GLOBALS->time_scale); }
 	
-			if(n->curr->time==time)
+			if(n->curr->time==tim)
 				{
 				DEBUG(printf("Warning: String Glitch at time ["TTFormat"] Signal [%p].\n",
-					time, n));
+					tim, n));
 				if(n->curr->v.h_vector) free_2(n->curr->v.h_vector);
 				n->curr->v.h_vector=vector;		/* we have a glitch! */
 	
@@ -1681,7 +1684,7 @@ switch(ch)
 				{
 	                	he=histent_calloc();
 				he->flags=(HIST_STRING|HIST_REAL);
-	                	he->time=time;
+	                	he->time=tim;
 	                	he->v.h_vector=vector;
 	
 	                	n->curr->next=he;
@@ -1703,24 +1706,24 @@ switch(ch)
 		n->curr=he;
 		n->head.next=he;
 	
-		add_histent_p(time,n,ch,regadd, vector);
+		add_histent_p(tim,n,ch,regadd, vector);
 		rc = he;
 		}
 		else
 		{
-		if(regadd) { time*=(GLOBALS->time_scale); }
+		if(regadd) { tim*=(GLOBALS->time_scale); }
 	
 		if(
 		  (n->curr->v.h_vector&&vector&&(*(double *)n->curr->v.h_vector!=*(double *)vector))
-			||(time==GLOBALS->start_time_vcd_partial_c_2)
+			||(tim==GLOBALS->start_time_vcd_partial_c_2)
 			||(!n->curr->v.h_vector)
 			||(GLOBALS->vcd_preserve_glitches)
 			) /* same region == go skip */ 
 	        	{
-			if(n->curr->time==time)
+			if(n->curr->time==tim)
 				{
 				DEBUG(printf("Warning: Real number Glitch at time ["TTFormat"] Signal [%p].\n",
-					time, n));
+					tim, n));
 				if(n->curr->v.h_vector) free_2(n->curr->v.h_vector);
 				n->curr->v.h_vector=vector;		/* we have a glitch! */
 	
@@ -1735,7 +1738,7 @@ switch(ch)
 				{
 	                	he=histent_calloc();
 				he->flags=HIST_REAL;
-	                	he->time=time;
+	                	he->time=tim;
 	                	he->v.h_vector=vector;
 	
 	                	n->curr->next=he;
@@ -1761,24 +1764,24 @@ switch(ch)
 		n->curr=he;
 		n->head.next=he;
 	
-		add_histent_p(time,n,ch,regadd, vector);
+		add_histent_p(tim,n,ch,regadd, vector);
 		rc = he;
 		}
 		else
 		{
-		if(regadd) { time*=(GLOBALS->time_scale); }
+		if(regadd) { tim*=(GLOBALS->time_scale); }
 	
 		if(
 		  (n->curr->v.h_vector&&vector&&(strcmp(n->curr->v.h_vector,vector)))
-			||(time==GLOBALS->start_time_vcd_partial_c_2)
+			||(tim==GLOBALS->start_time_vcd_partial_c_2)
 			||(!n->curr->v.h_vector)
 			||(GLOBALS->vcd_preserve_glitches)
 			) /* same region == go skip */ 
 	        	{
-			if(n->curr->time==time)
+			if(n->curr->time==tim)
 				{
 				DEBUG(printf("Warning: Glitch at time ["TTFormat"] Signal [%p], Value [%c->%c].\n",
-					time, n, AN_STR[n->curr->v.h_val], ch));
+					tim, n, AN_STR[n->curr->v.h_val], ch));
 				if(n->curr->v.h_vector) free_2(n->curr->v.h_vector);
 				n->curr->v.h_vector=vector;		/* we have a glitch! */
 	
@@ -1792,7 +1795,7 @@ switch(ch)
 				else
 				{
 	                	he=histent_calloc();
-	                	he->time=time;
+	                	he->time=tim;
 	                	he->v.h_vector=vector;
 	
 	                	n->curr->next=he;
@@ -2368,8 +2371,32 @@ if(GLOBALS->partial_vcd)
 		t = GLOBALS->traces.first; while(t) { regen_trace_sweep(t); t = t->t_next; }
 		t = GLOBALS->traces.buffer; while(t) { regen_trace_sweep(t); t = t->t_next; }
 	
-	        signalarea_configure_event(GLOBALS->signalarea, NULL);
-	        wavearea_configure_event(GLOBALS->wavearea, NULL);
+		if ((GLOBALS->zoom_dyn) && (!GLOBALS->helpbox_is_active)) 
+			{
+			GLOBALS->tims.marker = GLOBALS->tims.last;
+			service_zoom_full(NULL, NULL);
+
+		        GLOBALS->signalwindow_width_dirty=1;
+		        MaxSignalLength();
+		        signalarea_configure_event(GLOBALS->signalarea, NULL);
+			}
+		else if ((GLOBALS->zoom_dyne) && (!GLOBALS->helpbox_is_active)) 
+			{
+			GLOBALS->tims.marker = GLOBALS->tims.last;
+			service_zoom_right(NULL, NULL);
+
+		        GLOBALS->signalwindow_width_dirty=1;
+		        MaxSignalLength();
+		        signalarea_configure_event(GLOBALS->signalarea, NULL);
+			}
+			else
+			{
+		        signalarea_configure_event(GLOBALS->signalarea, NULL);
+		        wavearea_configure_event(GLOBALS->wavearea, NULL);
+			}
+
+		update_maxmarker_labels();
+
 		gtkwave_gtk_main_iteration();
 		}
 	}
@@ -2380,8 +2407,26 @@ gtkwave_gtk_main_iteration();
 }
 
 /*
- * $Id: vcd_partial.c,v 1.7 2008/07/18 18:46:11 gtkwave Exp $
+ * $Id: vcd_partial.c,v 1.13 2009/01/12 18:46:00 gtkwave Exp $
  * $Log: vcd_partial.c,v $
+ * Revision 1.13  2009/01/12 18:46:00  gtkwave
+ * added marker nail-down during partial vcd w dynamic zoom
+ *
+ * Revision 1.12  2009/01/12 04:17:39  gtkwave
+ * added dynamic zoom for end for partial vcd
+ *
+ * Revision 1.11  2008/12/25 03:52:32  gtkwave
+ * -Wshadow warning fixes
+ *
+ * Revision 1.10  2008/12/04 19:21:00  gtkwave
+ * added zoom_dynamic option for partial VCD loading
+ *
+ * Revision 1.9  2008/10/12 02:56:20  gtkwave
+ * fix for blackout regions
+ *
+ * Revision 1.8  2008/09/17 04:33:38  gtkwave
+ * support for smaller timescales in VCD files
+ *
  * Revision 1.7  2008/07/18 18:46:11  gtkwave
  * bitblasted vector relinking fix, disable hier pack in legacy+partial vcdload
  *
