@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Tony Bybell 2005-7.
+ * Copyright (c) Tony Bybell 2005-8.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -233,7 +233,7 @@ else
 }
 
 
-void recurse_build(vcdsav_Tree *vt, vcdsav_Tree ***hp)
+static void recurse_build(vcdsav_Tree *vt, vcdsav_Tree ***hp)
 {
 if(vt->left) recurse_build(vt->left, hp);
 
@@ -305,8 +305,8 @@ int nodecnt = 0;
 vcdsav_Tree *vt = NULL;
 vcdsav_Tree **hp_clone = GLOBALS->hp_vcd_saver_c_1;
 nptr n;
-ExtNode *e;
-int msi, lsi;
+/* ExtNode *e; */
+/* int msi, lsi; */
 int i;
 TimeType prevtime = LLDescriptor(-1);
 time_t walltime;
@@ -317,6 +317,11 @@ char *row_data = NULL;
 struct lt_trace *lt = NULL;
 int lxt = (export_typ == WAVE_EXPORT_LXT);
 
+if(export_typ == WAVE_EXPORT_TIM)
+	{
+	return(do_timfile_save(fname));
+	}
+
 errno = 0;
 if(lxt)
 	{
@@ -343,8 +348,8 @@ while(t)
 			{
 			n = t->n.nd;
 			if(n->expansion) n = n->expansion->parent;
-			e = n->ext;
-			if(e) { msi = e->msi; lsi = e->lsi; } else { msi = lsi = -1; }
+			/* e = n->ext; */
+			/* if(e) { msi = e->msi; lsi = e->lsi; } else { msi = lsi = -1; } */
 			vt = vcdsav_splay(n, vt);
 			if(!vt || vt->item != n)
 				{
@@ -375,8 +380,8 @@ while(t)
 						n = bt->nodes[i];
 	
 						if(n->expansion) n = n->expansion->parent;
-						e = n->ext;
-						if(e) { msi = e->msi; lsi = e->lsi; } else { msi = lsi = -1; }
+						/* e = n->ext; */
+						/* if(e) { msi = e->msi; lsi = e->lsi; } else { msi = lsi = -1; } */
 						vt = vcdsav_splay(n, vt);
 						if(!vt || vt->item != n)
 							{
@@ -854,9 +859,596 @@ if(*nh_curr->name == '\\')
 return(nh_curr->name);
 }
 
+
+/****************************************/
+/***                                  ***/
+/*** output in timing analyzer format ***/
+/***                                  ***/
+/****************************************/
+
+static void write_hptr_trace(Trptr t, int *whichptr, TimeType tmin, TimeType tmax)
+{
+nptr n = t->n.nd;
+hptr *ha = n->harray;
+int numhist = n->numhist;
+int i;
+unsigned char h_val = AN_X;
+gboolean first;
+gboolean invert = ((t->flags&TR_INVERT) != 0);
+int edges = 0;
+
+first = TRUE;
+for(i=0;i<numhist;i++)
+	{
+	if(ha[i]->time < tmin)
+		{
+		}
+	else
+	if(ha[i]->time > tmax)
+		{
+		break;
+		}
+	else
+		{
+		if((ha[i]->time != tmin) || (!first))
+			{
+			edges++;
+			}
+
+		first = FALSE;
+		}
+	}
+
+
+first = TRUE;
+for(i=0;i<numhist;i++)
+	{
+	if(ha[i]->time < tmin)
+		{
+		h_val = invert ? AN_STR_INV[ha[i]->v.h_val] : AN_STR[ha[i]->v.h_val];	
+		}
+	else
+	if(ha[i]->time > tmax)
+		{
+		break;
+		}
+	else
+		{
+		if(first)
+			{
+			gboolean skip_this = (ha[i]->time == tmin);
+
+			if(skip_this)
+				{
+				h_val = invert ? AN_STR_INV[ha[i]->v.h_val] : AN_STR[ha[i]->v.h_val];
+				}
+
+			fprintf(GLOBALS->f_vcd_saver_c_1,
+				"Digital_Signal\n"
+				"     Position:          %d\n"
+				"     Height:            24\n"
+				"     Space_Above:       24\n"
+				"     Name:              %s\n"
+				"     Start_State:       %c\n"
+				"     Number_Edges:      %d\n"
+				"     Rise_Time:         0.2\n"
+				"     Fall_Time:         0.2\n",
+					*whichptr,
+					t->name,
+					h_val,
+					edges);
+			first = FALSE;			
+
+			if(skip_this) 
+				{
+				continue;
+				}
+			}
+
+		h_val = invert ? AN_STR_INV[ha[i]->v.h_val] : AN_STR[ha[i]->v.h_val];
+		fprintf(GLOBALS->f_vcd_saver_c_1, "          Edge:               "TTFormat".0 %c\n", ha[i]->time, h_val);
+		}
+	}		
+
+if(first)
+	{
+	/* need to emit blank trace */
+	fprintf(GLOBALS->f_vcd_saver_c_1,
+		"Digital_Signal\n"
+		"     Position:          %d\n"
+		"     Height:            24\n"
+		"     Space_Above:       24\n"
+		"     Name:              %s\n"
+		"     Start_State:       %c\n"
+		"     Number_Edges:      %d\n"
+		"     Rise_Time:         10.0\n"
+		"     Fall_Time:         10.0\n",
+			*whichptr,
+			t->name,
+			h_val,
+			edges);
+	}
+
+(*whichptr)++;
+}
+
+/***/
+
+static void format_value_string(char *s)
+{
+char *s_orig = s;
+
+if((s)&&(*s))
+	{
+	gboolean is_all_z = TRUE;
+	gboolean is_all_x = TRUE;
+
+	while(*s)
+		{
+		if((*s != 'z') && (*s != 'Z'))
+			{
+			is_all_z = FALSE;
+			}
+		if((*s != 'x') && (*s != 'X'))
+			{
+			is_all_x = FALSE;
+			}
+
+		/* if(isspace(*s)) *s='_'; ...not needed */
+		s++;
+		}
+	
+	if(is_all_z)
+		{
+		*(s_orig++) = 'Z';		
+		*(s_orig) = 0;		
+		}
+	else
+	if(is_all_x)
+		{
+		*(s_orig++) = 'X';		
+		*(s_orig) = 0;		
+		}
+	}
+}
+
+static char *get_hptr_vector_val(Trptr t, hptr h)
+{
+char *ascii = NULL;
+
+if(h->time < LLDescriptor(0)) 
+	{
+	ascii=strdup_2("X");
+	}
+else
+if(h->flags&HIST_REAL)
+	{
+        if(!(h->flags&HIST_STRING))
+        	{               
+                ascii=convert_ascii_real((double *)h->v.h_vector);
+                }
+                else
+                {
+                ascii=convert_ascii_string((char *)h->v.h_vector);
+                }        
+	}
+        else
+        {
+        ascii=convert_ascii_vec(t,h->v.h_vector);
+        }
+
+format_value_string(ascii);
+return(ascii);
+}
+
+static const char *vcdsav_dtypes[] = { "Bin", "Hex", "Text" };
+
+static int determine_trace_data_type(char *s, int curtype)
+{
+int i;
+
+if((s) && (curtype != VCDSAV_IS_TEXT))
+	{
+	int len = strlen(s);
+	for(i=0;i<len;i++)
+		{
+		int ch = (int)((unsigned char)s[i]);
+
+		if(strchr("01xXzZhHuUwWlL-?_", ch))
+			{
+			/* nothing */
+			}
+		else if(strchr("23456789aAbBcCdDeEfF", ch))
+			{
+			curtype = VCDSAV_IS_HEX;
+			}
+		else
+			{
+			curtype = VCDSAV_IS_TEXT;
+			break;
+			}
+		}
+	}
+
+return(curtype);
+}
+
+
+static void write_hptr_trace_vector(Trptr t, int *whichptr, TimeType tmin, TimeType tmax)
+{
+nptr n = t->n.nd;
+hptr *ha = n->harray;
+int numhist = n->numhist;
+int i;
+char *h_val = NULL;
+gboolean first;
+int edges = 0;
+int curtype = VCDSAV_IS_BIN;
+
+first = TRUE;
+for(i=0;i<numhist;i++)
+	{
+	if(ha[i]->time < tmin)
+		{
+		}
+	else
+	if(ha[i]->time > tmax)
+		{
+		break;
+		}
+	else
+		{
+		char *s = get_hptr_vector_val(t, ha[i]);
+		if(s)
+			{
+			curtype = determine_trace_data_type(s, curtype);
+			free_2(s);
+			}
+
+		if((ha[i]->time != tmin) || (!first))
+			{
+			edges++;
+			}
+
+		first = FALSE;
+		}
+	}
+
+
+first = TRUE;
+for(i=0;i<numhist;i++)
+	{
+	if(ha[i]->time < tmin)
+		{
+		if(h_val) free_2(h_val); 
+		h_val = get_hptr_vector_val(t, ha[i]);
+		}
+	else
+	if(ha[i]->time > tmax)
+		{
+		break;
+		}
+	else
+		{
+		if(first)
+			{
+			gboolean skip_this = (ha[i]->time == tmin);
+
+			if(skip_this)
+				{
+				if(h_val) free_2(h_val); 
+				h_val = get_hptr_vector_val(t, ha[i]);
+				}
+
+			fprintf(GLOBALS->f_vcd_saver_c_1,
+				"Digital_Bus\n"
+				"     Position:          %d\n"
+				"     Height:            24\n"
+				"     Space_Above:       24\n"
+				"     Name:              %s\n"
+				"     Start_State:       %s\n"
+				"     State_Format:      %s\n"
+				"     Number_Edges:      %d\n"
+				"     Rise_Time:         0.2\n"
+				"     Fall_Time:         0.2\n",
+					*whichptr,
+					t->name,
+					h_val,
+					vcdsav_dtypes[curtype],
+					edges);
+			first = FALSE;			
+
+			if(skip_this) 
+				{
+				continue;
+				}
+			}
+
+		if(h_val) free_2(h_val); 
+		h_val = get_hptr_vector_val(t, ha[i]);
+		fprintf(GLOBALS->f_vcd_saver_c_1, "          Edge:               "TTFormat".0 %s\n", ha[i]->time, h_val);
+		}
+	}		
+
+if(first)
+	{
+	/* need to emit blank trace */
+	fprintf(GLOBALS->f_vcd_saver_c_1,
+		"Digital_Bus\n"
+		"     Position:          %d\n"
+		"     Height:            24\n"
+		"     Space_Above:       24\n"
+		"     Name:              %s\n"
+		"     Start_State:       %s\n"
+		"     State_Format:      %s\n"
+		"     Number_Edges:      %d\n"
+		"     Rise_Time:         10.0\n"
+		"     Fall_Time:         10.0\n",
+			*whichptr,
+			t->name,
+			h_val,
+			vcdsav_dtypes[curtype],
+			edges);
+	}
+
+if(h_val) free_2(h_val); 
+(*whichptr)++;
+}
+
+/***/
+
+static char *get_vptr_vector_val(Trptr t, vptr v)
+{
+char *ascii = NULL;
+
+if(v->time < LLDescriptor(0)) 
+	{
+	ascii=strdup_2("X");
+	}
+else
+        {
+        ascii=convert_ascii(t,v);
+        }
+
+if(!ascii)
+	{
+	ascii=strdup_2("X");
+	}
+
+format_value_string(ascii);
+return(ascii);
+}
+
+
+static void write_vptr_trace(Trptr t, int *whichptr, TimeType tmin, TimeType tmax)
+{
+vptr *ha = t->n.vec->vectors;
+int numhist = t->n.vec->numregions;
+int i;
+char *h_val = NULL;
+gboolean first;
+int edges = 0;
+int curtype = VCDSAV_IS_BIN;
+
+first = TRUE;
+for(i=0;i<numhist;i++)
+	{
+	if(ha[i]->time < tmin)
+		{
+		}
+	else
+	if(ha[i]->time > tmax)
+		{
+		break;
+		}
+	else
+		{
+		char *s = get_vptr_vector_val(t, ha[i]);
+		if(s)
+			{
+			curtype = determine_trace_data_type(s, curtype);
+			free_2(s);
+			}
+
+		if((ha[i]->time != tmin) || (!first))
+			{
+			edges++;
+			}
+
+		first = FALSE;
+		}
+	}
+
+
+first = TRUE;
+for(i=0;i<numhist;i++)
+	{
+	if(ha[i]->time < tmin)
+		{
+		if(h_val) free_2(h_val); 
+		h_val = get_vptr_vector_val(t, ha[i]);
+		}
+	else
+	if(ha[i]->time > tmax)
+		{
+		break;
+		}
+	else
+		{
+		if(first)
+			{
+			gboolean skip_this = (ha[i]->time == tmin);
+
+			if(skip_this)
+				{
+				if(h_val) free_2(h_val); 
+				h_val = get_vptr_vector_val(t, ha[i]);
+				}
+
+			fprintf(GLOBALS->f_vcd_saver_c_1,
+				"Digital_Bus\n"
+				"     Position:          %d\n"
+				"     Height:            24\n"
+				"     Space_Above:       24\n"
+				"     Name:              %s\n"
+				"     Start_State:       %s\n"
+				"     State_Format:      %s\n"
+				"     Number_Edges:      %d\n"
+				"     Rise_Time:         0.2\n"
+				"     Fall_Time:         0.2\n",
+					*whichptr,
+					t->name,
+					h_val,
+					vcdsav_dtypes[curtype],
+					edges);
+			first = FALSE;			
+
+			if(skip_this) 
+				{
+				continue;
+				}
+			}
+
+		if(h_val) free_2(h_val); 
+		h_val = get_vptr_vector_val(t, ha[i]);
+		fprintf(GLOBALS->f_vcd_saver_c_1, "          Edge:               "TTFormat".0 %s\n", ha[i]->time, h_val);
+		}
+	}		
+
+if(first)
+	{
+	/* need to emit blank trace */
+	fprintf(GLOBALS->f_vcd_saver_c_1,
+		"Digital_Bus\n"
+		"     Position:          %d\n"
+		"     Height:            24\n"
+		"     Space_Above:       24\n"
+		"     Name:              %s\n"
+		"     Start_State:       %s\n"
+		"     State_Format:      %s\n"
+		"     Number_Edges:      %d\n"
+		"     Rise_Time:         10.0\n"
+		"     Fall_Time:         10.0\n",
+			*whichptr,
+			t->name,
+			h_val,
+			vcdsav_dtypes[curtype],
+			edges);
+	}
+
+if(h_val) free_2(h_val); 
+(*whichptr)++;
+}
+
+
+static void write_tim_tracedata(Trptr t, int *whichptr, TimeType tmin, TimeType tmax)
+{
+if(!(t->flags&(TR_EXCLUDE|TR_BLANK|TR_ANALOG_BLANK_STRETCH)))
+	{
+        GLOBALS->shift_timebase=t->shift;
+        if(!t->vector)
+        	{
+                if(!t->n.nd->ext)
+                	{
+			write_hptr_trace(t, whichptr, tmin, tmax); /* single-bit */
+                        }
+                        else
+                        {
+			write_hptr_trace_vector(t, whichptr, tmin, tmax); /* multi-bit */
+                        }
+		}
+                else
+                {
+		write_vptr_trace(t, whichptr, tmin, tmax); /* synthesized/concatenated vector */
+                }
+	}
+}
+
+
+int do_timfile_save(const char *fname)
+{
+const char *time_prefix=WAVE_SI_UNITS;
+const double negpow[] = { 1.0, 1.0e-3, 1.0e-6, 1.0e-9, 1.0e-12, 1.0e-15, 1.0e-18, 1.0e-21 };
+char *pnt;        
+int offset;
+Trptr t = GLOBALS->traces.first;
+int i = 1; /* trace index in the .tim file */
+TimeType tmin, tmax;
+
+errno = 0;
+
+if((GLOBALS->tims.marker > LLDescriptor(0)) && (GLOBALS->tims.baseline > LLDescriptor(0)))
+	{
+	if(GLOBALS->tims.marker < GLOBALS->tims.baseline)
+		{
+	        tmin = GLOBALS->tims.marker;
+	        tmax = GLOBALS->tims.baseline;
+		}
+		else
+		{
+	        tmax = GLOBALS->tims.marker;
+	        tmin = GLOBALS->tims.baseline;
+		}
+	}
+	else
+	{
+        tmin = GLOBALS->min_time;
+        tmax = GLOBALS->max_time;
+	}
+
+GLOBALS->f_vcd_saver_c_1 = fopen(fname, "wb");
+if(!GLOBALS->f_vcd_saver_c_1)
+	{
+        return(VCDSAV_FILE_ERROR);
+        }
+
+pnt=strchr(time_prefix, (int)GLOBALS->time_dimension);
+if(pnt) { offset=pnt-time_prefix; } else offset=0;
+
+fprintf(GLOBALS->f_vcd_saver_c_1,
+	"Timing Analyzer Settings\n"
+	"     Time_Scale:        %E\n"
+	"     Time_Per_Division: %E\n"
+	"     NumberDivisions:   10\n"
+	"     Start_Time:        "TTFormat".0\n"
+	"     End_Time:          "TTFormat".0\n",
+
+	negpow[offset],
+	(tmax-tmin) / 10.0,
+	tmin,
+	tmax
+	);
+
+while(t)
+	{
+	write_tim_tracedata(t, &i, tmin, tmax);
+        t = GiveNextTrace(t);
+	}
+
+fclose(GLOBALS->f_vcd_saver_c_1);
+GLOBALS->f_vcd_saver_c_1 = NULL;
+
+return(errno ? VCDSAV_FILE_ERROR : VCDSAV_OK);
+}
+
 /*
- * $Id: vcd_saver.c,v 1.3 2008/07/18 17:27:01 gtkwave Exp $
+ * $Id: vcd_saver.c,v 1.8 2008/12/25 03:52:32 gtkwave Exp $
  * $Log: vcd_saver.c,v $
+ * Revision 1.8  2008/12/25 03:52:32  gtkwave
+ * -Wshadow warning fixes
+ *
+ * Revision 1.7  2008/12/16 19:28:20  gtkwave
+ * more warnings cleanups
+ *
+ * Revision 1.6  2008/12/06 19:55:53  gtkwave
+ * more adds to the timinganalyzer output writer
+ *
+ * Revision 1.5  2008/12/05 21:05:19  gtkwave
+ * changed lower limit for time compare in "X" generation
+ *
+ * Revision 1.4  2008/12/05 19:44:08  gtkwave
+ * prelim support for timinganalyzer file format export
+ *
  * Revision 1.3  2008/07/18 17:27:01  gtkwave
  * adding hierpack code
  *
