@@ -31,6 +31,11 @@
 
 void vlist_init_spillfile(void)
 {
+#if defined _MSC_VER || defined __MINGW32__
+GLOBALS->vlist_handle = tmpfile();
+fputc('!', GLOBALS->vlist_handle);
+GLOBALS->vlist_bytes_written = 1;
+#else
 int fd_dummy;
 char *nam = tmpnam_2(NULL, &fd_dummy);
 
@@ -39,11 +44,12 @@ if(nam)
 	GLOBALS->vlist_handle = fopen(nam, "w+b");
 	
 	unlink(nam);
-	if(fd_dummy >=0) close(fd_dummy);
+	if(fd_dummy >=0) { close(fd_dummy); free_2(nam); }
 
 	fputc('!', GLOBALS->vlist_handle);
 	GLOBALS->vlist_bytes_written = 1;
 	}
+#endif
 }
 
 void vlist_kill_spillfile(void)
@@ -774,8 +780,14 @@ free_2(mem - WAVE_ZIVWRAP);
 
 
 /*
- * $Id: vlist.c,v 1.12 2008/07/13 00:15:41 gtkwave Exp $
+ * $Id: vlist.c,v 1.14 2008/12/27 19:55:06 gtkwave Exp $
  * $Log: vlist.c,v $
+ * Revision 1.14  2008/12/27 19:55:06  gtkwave
+ * remove stray tempfiles under MinGW
+ *
+ * Revision 1.13  2008/10/14 00:53:46  gtkwave
+ * enabled tcl scripts to call existing gtkwave style scripted menu functions
+ *
  * Revision 1.12  2008/07/13 00:15:41  gtkwave
  * fix for short reads when --giga option is enabled
  *
