@@ -395,9 +395,9 @@ if((GLOBALS->fast_tree_sort) && (!GLOBALS->do_hier_compress))
 	init_tree();		
 	for(i=0;i<GLOBALS->numfacs;i++)	
 		{
-		char *n = GLOBALS->facs[i]->name;
+		char *nf = GLOBALS->facs[i]->name;
 		int was_packed;
-		char *recon = hier_decompress_flagged(n, &was_packed);
+		char *recon = hier_decompress_flagged(nf, &was_packed);
 
 		if(was_packed)
 		        {
@@ -406,7 +406,7 @@ if((GLOBALS->fast_tree_sort) && (!GLOBALS->do_hier_compress))
 		        }
 		        else
 		        {
-		        build_tree_from_name(n, i);
+		        build_tree_from_name(nf, i);
 		        }        
 		}
 /* SPLASH */                            splash_sync(5, 5);  
@@ -462,7 +462,7 @@ return(GLOBALS->max_time);
 /*
  * vzt callback (only does bits for now)
  */
-static void vzt_callback(struct vzt_rd_trace **lt, lxtint64_t *time, lxtint32_t *facidx, char **value)
+static void vzt_callback(struct vzt_rd_trace **lt, lxtint64_t *tim, lxtint32_t *facidx, char **value)
 {
 struct HistEnt *htemp = histent_calloc();
 struct lx2_entry *l2e = GLOBALS->vzt_table_vzt_c_1+(*facidx);
@@ -476,7 +476,7 @@ if(GLOBALS->busycnt_vzt_c_2==WAVE_BUSY_ITER)
 	GLOBALS->busycnt_vzt_c_2 = 0;
 	}
 
-/* fprintf(stderr, "%lld %d %s\n", *time, *facidx, *value); */
+/* fprintf(stderr, "%lld %d %s\n", *tim, *facidx, *value); */
 
 if(!(f->flags&(VZT_RD_SYM_F_DOUBLE|VZT_RD_SYM_F_STRING)))
 	{
@@ -513,7 +513,7 @@ else	/* string */
 	}
 
 
-htemp->time = (*time) * (GLOBALS->time_scale);
+htemp->time = (*tim) * (GLOBALS->time_scale);
 
 if(l2e->histent_head)
 	{
@@ -803,8 +803,11 @@ for(txidx=0;txidx<GLOBALS->numfacs;txidx++)
 }
 
 /*
- * $Id: vzt.c,v 1.4 2008/07/20 20:48:08 gtkwave Exp $
+ * $Id: vzt.c,v 1.5 2008/12/25 03:28:55 gtkwave Exp $
  * $Log: vzt.c,v $
+ * Revision 1.5  2008/12/25 03:28:55  gtkwave
+ * -Wshadow warning fixes
+ *
  * Revision 1.4  2008/07/20 20:48:08  gtkwave
  * compressed hierarchy support
  *
